@@ -160,13 +160,15 @@ void About::about()
     option_lv->setPreColors( row, FieldListView::PRECOLOR_NOTSELORACT );
 #endif
 
+    row = option_lv->addRow();
+    option_lv->setText( row, 0, "Font engine:" );
 #ifdef HAVE_XFT
     /* XFT */
-    row = option_lv->addRow();
-    option_lv->setText( row, 0, "XFT support:" );
-    option_lv->setText( row, 1, "yes" );
-    option_lv->setPreColors( row, FieldListView::PRECOLOR_NOTSELORACT );
+    option_lv->setText( row, 1, "Xft" );
+#else
+    option_lv->setText( row, 1, "X11" );
 #endif
+    option_lv->setPreColors( row, FieldListView::PRECOLOR_NOTSELORACT );
 
     /* libmagic */
     row = option_lv->addRow();
@@ -218,6 +220,16 @@ void About::about()
     option_lv->setText( row, 1, str1 );
     option_lv->setPreColors( row, FieldListView::PRECOLOR_NOTSELORACT );
 
+    /* inotify */
+    row = option_lv->addRow();
+    option_lv->setText( row, 0, "Inotify support:" );
+#ifdef HAVE_INOTIFY
+    option_lv->setText( row, 1, "yes" );
+#else
+    option_lv->setText( row, 1, "no" );
+#endif
+    option_lv->setPreColors( row, FieldListView::PRECOLOR_NOTSELORACT );
+
 #ifdef USE_MEM_SYSTEM
     row = option_lv->addRow();
     option_lv->setText( row, 0, "SLOW memory system:" );
