@@ -1,6 +1,6 @@
 /* aguix.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2009 Ralf Hoffmann.
+ * Copyright (C) 2001-2009,2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -31,6 +31,10 @@
 #include <signal.h>
 #endif
 
+#ifdef HAVE_XINERAMA
+#  include <X11/extensions/Xinerama.h>
+#endif
+
 #ifdef USE_XIM
 
 #ifndef HAVE_XSETIMVALUES_PROTOTYPE
@@ -266,6 +270,7 @@ int AGUIX::initX()
 
   XA_NET_WM_NAME = XInternAtom( dsp, "_NET_WM_NAME", False );
   XA_NET_WM_ICON_NAME = XInternAtom( dsp, "_NET_WM_ICON_NAME", False );
+  XA_TARGETS = XInternAtom( dsp, "TARGETS", False );
 
   initOK=True;
   return 0;
@@ -853,6 +858,16 @@ Message *AGUIX::wait4mess( int mode )
 			PropModeReplace,
 			(unsigned char*)clipboard_string.c_str(),
 			clipboard_string.length());
+      } else if ( LastEvent.xselectionrequest.target == XA_TARGETS ) {
+          // send the list of supported atoms
+          Atom supported_targets[] = { XA_TARGETS, XA_STRING };
+          XChangeProperty( dsp,
+                           ev.xselection.requestor,
+                           ev.xselection.property,
+                           XA_ATOM,
+                           8, PropModeReplace,
+                           (unsigned char *)supported_targets,
+                           sizeof( supported_targets ) );
       } else {
 	ev.xselection.property=None;
       }
@@ -2238,7 +2253,7 @@ const AWindow* AGUIX::getTransientWindow() const
 
 int AGUIX::addDefaultColors()
 {
-    if ( AddColor( 160, 160, 160 ).getColor() < 0 ) return -1;
+    if ( AddColor( 180, 180, 180 ).getColor() < 0 ) return -1;
     if ( AddColor( 0, 0, 0 ).getColor() < 0 ) return -1;
     if ( AddColor( 255, 255, 255 ).getColor() < 0 ) return -1;
     if ( AddColor( 0, 85, 187).getColor() < 0 ) return -1;
@@ -2594,15 +2609,17 @@ void AGUIX::drawBorder( Drawable buffer, GC usegc, bool pressed, int x, int y, i
 
 Atom AGUIX::getAtom( atom_name_t name ) const
 {
-  switch ( name ) {
-    case CLOSE_ATOM:
-      return WM_delete_window;
-    case NET_WM_NAME_ATOM:
-      return XA_NET_WM_NAME;
-    case NET_WM_ICON_NAME_ATOM:
-      return XA_NET_WM_ICON_NAME;
-  }
-  return None;
+    switch ( name ) {
+        case CLOSE_ATOM:
+            return WM_delete_window;
+        case NET_WM_NAME_ATOM:
+            return XA_NET_WM_NAME;
+        case NET_WM_ICON_NAME_ATOM:
+            return XA_NET_WM_ICON_NAME;
+        case TARGETS_ATOM:
+            return XA_TARGETS;
+    }
+    return None;
 }
 
 void AGUIX::setColorForName( const std::string &name, int col )
@@ -2846,3 +2863,53 @@ void AGUIX::copyToClipboard( const std::string &s )
         clipboard_string = "";
     }
 }
+
+void AGUIX::getLargestDimensionOfCurrentScreen( int *x, int *y,
+                                                int *width, int *height )
+{
+#ifdef HAVE_XINERAMA
+    XineramaScreenInfo *xinerama_info;
+    int number_of_xinerama_screens = 0;
+    int mx, my;
+    bool found = false;
+
+    queryRootPointer( &mx, &my );
+
+    xinerama_info = XineramaQueryScreens( dsp,
+                                          &number_of_xinerama_screens );
+
+    if ( xinerama_info != NULL ) {
+        int l_x = 0, l_y = 0, l_w = 0, l_h = 0;
+        for ( int i = 0; i < number_of_xinerama_screens; i++ ) {
+            if ( mx >= xinerama_info[i].x_org &&
+                 my >= xinerama_info[i].y_org &&
+                 mx < xinerama_info[i].x_org + xinerama_info[i].width &&
+                 my < xinerama_info[i].y_org + xinerama_info[i].height ) {
+                if ( xinerama_info[i].width > l_w &&
+                     xinerama_info[i].height > l_h ) {
+                    l_x = xinerama_info[i].x_org;
+                    l_y = xinerama_info[i].y_org;
+                    l_w = xinerama_info[i].width;
+                    l_h = xinerama_info[i].height;
+                    found = true;
+                }
+            }
+        }
+
+        XFree( xinerama_info );
+
+        if ( found ) {
+            if ( x ) *x = l_x;
+            if ( y ) *y = l_y;
+            if ( width ) *width = l_w;
+            if ( height ) *height = l_h;
+            return;
+        }
+    }
+#endif
+
+    if ( x ) *x = 0;
+    if ( y ) *y = 0;
+    if ( width ) *width = getRootWindowWidth();
+    if ( height ) *height = getRootWindowHeight();
+}
