@@ -1,6 +1,6 @@
 /* button.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2005,2010 Ralf Hoffmann.
+ * Copyright (C) 2001-2005,2010,2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -580,3 +580,15 @@ void Button::prepareBG( bool force )
   
   _aguix->SetWindowBG( win, newbg );
 }
+
+int Button::getMaximumWidth()
+{
+    int max_w = _aguix->getTextWidth( text[0], font ) + _aguix->getTextWidth( "  ", font );
+
+    if ( dual ) {
+        int t_max_w = _aguix->getTextWidth( text[1], font ) + _aguix->getTextWidth( "  ", font );
+        if ( t_max_w > max_w ) max_w = t_max_w;
+    }
+
+    return max_w;
+}
