@@ -217,11 +217,11 @@ bool ChooseButton::isInside(int px,int py) const
 
 bool ChooseButton::handleMessage(XEvent *E,Message *msg)
 {
-  bool returnvalue;
+    //bool returnvalue;
 
   if ( isCreated() == false ) return false;
 
-  returnvalue=false;
+  //returnvalue=false;
   if((msg->type==ButtonPress)||(msg->type==ButtonRelease)) {
     if ( msg->window == win || msg->window == lwin ) {
       takeFocus();
@@ -240,7 +240,7 @@ bool ChooseButton::handleMessage(XEvent *E,Message *msg)
 	cross=true;
 	agmsg->choose.state=state;
         msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
-	returnvalue=true;
+	//returnvalue=true;
       } else {
         if(state==instate) {
           AGMessage *agmsg = AGUIX_allocAGMessage();
