@@ -3200,6 +3200,7 @@ void FieldListView::handleHeader( Message *msg )
   int sx = -1, ex = -1, mx;
   int f, last_f = -1;
   int resizeable_f;
+  bool do_redraw = true;
 
   if ( msg == NULL ) return;
 
@@ -3324,6 +3325,8 @@ void FieldListView::handleHeader( Message *msg )
 	header_cursor_set = false;
       }
     }
+
+    do_redraw = false;
   } else if ( msg->type == ButtonRelease && headerMode != HEADER_IDLE ) {
     if ( headerMode == HEADER_DRAG ) {
       // in drag mode ungrab pointer
@@ -3352,10 +3355,13 @@ void FieldListView::handleHeader( Message *msg )
     fieldtextclicked = -1;
     headerMode = HEADER_IDLE;
   }
-  redrawHeader();
 
-  hh = getHeaderHeight();
-  drawBuffer( ox, oy - hh, getInnerWidth(), hh );
+  if ( do_redraw ) {
+      redrawHeader();
+
+      hh = getHeaderHeight();
+      drawBuffer( ox, oy - hh, getInnerWidth(), hh );
+  }
 }
 
 void FieldListView::setHeaderFG( int col )
