@@ -1,6 +1,6 @@
 /* fieldlistview.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2010 Ralf Hoffmann.
+ * Copyright (C) 2002-2010,2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -125,7 +125,9 @@ public:
   void setMBG( int color );
   
   int maximizeX();
+  int getMaximumWidth();
   int maximizeY();
+  int getMaximumHeight();
 
   void showRow( int row, bool redraw = true);
   
