@@ -325,12 +325,11 @@ bool KarteiButton::handleMessage(XEvent *E,Message *msg)
   if ( ( msg->type == ButtonPress ) ||
        ( msg->type == ButtonRelease ) ) {
     if ( msg->window == win ) {
-      int mx, my, opt;
+      int mx, opt;
 
       takeFocus();
 
       mx = msg->mousex;
-      my = msg->mousey;
       opt = findClickedOption( mx );
       if(msg->type==ButtonPress) {
 	if ( opt >= 0 ) {
