@@ -1,6 +1,6 @@
 /* lowlevelfunc.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2006,2010 Ralf Hoffmann.
+ * Copyright (C) 2001-2006,2010-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -263,7 +263,7 @@ char *shrinkstring( const char *str, int maxlen, AWidth &lencalc )
       rwidth = lencalc.getWidth( trystr );
       if ( rwidth <= rest_width ) hitstr = trystr;
       else break;
-      UTF8::movePosToPrevChar( str, pos );
+      if ( UTF8::movePosToPrevChar( str, pos ) < 1 ) break;
       trystr = str + pos;
     }
     
