@@ -128,12 +128,9 @@ void PopUpMenu::show( int x, int y, popup_show_t show_type )
                with the given window as generating window. Setting it to true
                will send the events as usual with the currently focused window
                as  the generating window. */
-            m_grabbed_keyboard = XGrabKeyboard( _aguix->getDisplay(),
-                                                win,
-                                                False,
-                                                GrabModeAsync,
-                                                GrabModeAsync,
-                                                CurrentTime );
+
+            checkAndGrabKeyboard();
+
             m_grabbed_pointer = XGrabPointer( _aguix->getDisplay(),
                                               RootWindow( _aguix->getDisplay(),
                                                           _aguix->getScreen() ),
@@ -1000,3 +997,26 @@ void PopUpMenu::changeFocusTo( PopUpMenu *owner, change_focus_run_t mode )
         }
     }
 }
+
+void PopUpMenu::checkAndGrabKeyboard()
+{
+    if ( isCreated() == true &&
+         m_parent_menu == NULL &&
+         onScreen == true &&
+         m_grabbed_keyboard != 0 ) {
+
+        //std::cout << "Regrab:";
+
+        m_grabbed_keyboard = XGrabKeyboard( _aguix->getDisplay(),
+                                            win,
+                                            False,
+                                            GrabModeAsync,
+                                            GrabModeAsync,
+                                            CurrentTime );
+        //std::cout << m_grabbed_keyboard << std::endl;
+
+        if ( m_grabbed_keyboard == 0 ) {
+            //std::cout << "Success" << std::endl;
+        }
+    }
+}
