@@ -1,6 +1,6 @@
 /* stringgadget.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2008,2010 Ralf Hoffmann.
+ * Copyright (C) 2001-2008,2010,2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -460,6 +460,12 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 	      if(strongkeycapture==true) returnvalue=true;
 	      if(content.getSelStart()!=content.getSelEnd()) {
 		removeSelection();
+
+		returnvalue = true;
+		agmsg = AGUIX_allocAGMessage();
+		agmsg->type = AG_STRINGGADGET_CONTENTCHANGE;
+		agmsg->stringgadget.sg = this;
+                msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
 	      } else if((content.getCursorPos()<len)&&(len>0)) {
                 content.removeRange( content.getCursorPos(), content.getCursorPos() );
 		returnvalue=true;
@@ -473,6 +479,12 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 	      if(strongkeycapture==true) returnvalue=true;
 	      if(content.getSelEnd()!=content.getSelStart()) {
 		removeSelection();
+
+		returnvalue = true;
+		agmsg = AGUIX_allocAGMessage();
+		agmsg->type = AG_STRINGGADGET_CONTENTCHANGE;
+		agmsg->stringgadget.sg = this;
+                msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
 	      } else if(content.getCursorPos()>0) {
                 int prev_char = content.getCursorPos();
                 UTF8::movePosToPrevChar( content.getText(), prev_char );
@@ -1245,3 +1257,14 @@ void StringGadget::changeHeightForCurFont()
   }
   resize( getWidth(), ch + 2 * getBorderWidth() );
 }
+
+void StringGadget::setSelection( int start, int end, bool copy_selection )
+{
+    content.setSelStart( start );
+    content.setSelEnd( end );
+
+    if ( copy_selection == true ) {
+        applySelection();
+    }
+    redraw();
+}
