@@ -1,6 +1,6 @@
 /* textview.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2011 Ralf Hoffmann.
+ * Copyright (C) 2005-2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -185,6 +185,9 @@ bool TextView::handleMessage(XEvent *E,Message *msg)
   if ( msg->type == Expose &&
        msg->window == win ) {
       drawBuffer( msg->x, msg->y, msg->width, msg->height );
+  } else if ( msg->type == MapNotify &&
+       msg->window == win ) {
+      redraw();
   } else if ( msg->type == KeyPress ) {
     if ( ( getAcceptFocus() == true ) && ( getHasFocus() == true ) ) {
       if ( isVisible() == true ) {
@@ -195,6 +198,37 @@ bool TextView::handleMessage(XEvent *E,Message *msg)
 	}
       }
     }
+  } else if ( msg->type == MotionNotify &&
+              msg->window == win ) {
+      int mx, my;
+
+      _aguix->queryPointer( win, &mx, &my );
+
+      std::pair< int, int > cur = getTextPosForMousePos( mx, my );
+
+      if ( cur != m_button_press_unwrapped_line_pos ) {
+          int cur_sel = - 1, cur_off = -1;
+
+          getSelectionEnd( cur_sel, cur_off );
+
+          if ( cur_sel != cur.first || cur_off != cur.second ) {
+              if ( m_button_press_unwrapped_line_pos.first < cur.first ||
+                   ( m_button_press_unwrapped_line_pos.first == cur.first &&
+                     m_button_press_unwrapped_line_pos.second < cur.second ) ) {
+                  setSelectionStart( m_button_press_unwrapped_line_pos.first,
+                                     m_button_press_unwrapped_line_pos.second );
+                  setSelectionEnd( cur.first,
+                                   cur.second );
+              } else {
+                  setSelectionStart( cur.first,
+                                     cur.second );
+                  setSelectionEnd( m_button_press_unwrapped_line_pos.first,
+                                   m_button_press_unwrapped_line_pos.second );
+              }
+
+              redraw();
+          }
+      }
   } else if ( ( msg->type == ButtonPress ) && ( msg->window == win ) ) {
     if ( ( msg->button == Button4 ) || ( msg->button == Button5 ) ) {
       gettimeofday( &t2, NULL );
@@ -225,7 +259,17 @@ bool TextView::handleMessage(XEvent *E,Message *msg)
       _lastwheel = t2;
     } else if ( msg->button == Button1 ) {
       applyFocus( this );
+
+      clearSelection();
+
+      redraw();
+
+      m_button_press_unwrapped_line_pos = getTextPosForMousePos( msg->mousex, msg->mousey );
     }
+  } else if ( msg->type == ButtonRelease && msg->window == win ) {
+      if ( msg->button == Button1 ) {
+          copySelectionToClipboard();
+      }
   }
 
   return AWindow::handleMessage( E, msg );
@@ -1099,3 +1143,92 @@ void TextView::checkForEndReached()
         }
     }
 }
+
+std::pair< int, int > TextView::getTextPosForMousePos( int x, int y )
+{
+    int elementHeight;
+
+    if ( font == NULL ) elementHeight = _aguix->getCharHeight();
+    else elementHeight = font->getCharHeight();
+
+    int bw = ( _display_focus == true ) ? 3 : 2;
+
+    int base_y = y - bw;
+
+    int relative_row = base_y / elementHeight;
+
+    if ( base_y < 0 ) relative_row--;
+
+    int base_x = x - bw;
+    base_x -= getTextStartOffset();
+
+    if ( base_x < 0 ) base_x = 0;
+
+    int absolute_row = relative_row + vbar->getOffset();
+
+    std::pair<int,int> cur_line = ts.getRealLinePair( absolute_row );
+
+    if ( cur_line.first < 0 ) return cur_line;
+
+    int prev_sublines_chars = 0;
+
+    if ( cur_line.second > 0 ) {
+        for ( int sl = 0; sl < cur_line.second; sl++ ) {
+            std::string s;
+
+            ts.getLine( absolute_row - cur_line.second + sl, 0, s );
+            prev_sublines_chars += s.size();
+        }
+    }
+
+    std::string clicked_line;
+
+    ts.getLine( absolute_row, 0, clicked_line );
+
+    int offset_length = ts.getAWidth().getStrlen4WidthMaxlen( clicked_line.c_str(), base_x / 2, base_x, NULL );
+
+    return std::make_pair( cur_line.first, prev_sublines_chars + offset_length );
+}
+
+void TextView::copySelectionToClipboard()
+{
+    std::string s;
+
+    int unwrapped_start_line, unwrapped_start_offset,
+        unwrapped_end_line, unwrapped_end_offset;
+
+    getSelectionStart( unwrapped_start_line, unwrapped_start_offset );
+    getSelectionEnd( unwrapped_end_line, unwrapped_end_offset );
+
+    if ( unwrapped_start_line >= 0 && unwrapped_end_line >= unwrapped_start_line ) {
+
+        if ( unwrapped_start_line == unwrapped_end_line ) {
+            ts.getUnwrappedLine( unwrapped_start_line,
+                                 unwrapped_start_offset,
+                                 unwrapped_end_offset - unwrapped_start_offset, s );
+        } else {
+            ts.getUnwrappedLine( unwrapped_start_line,
+                                 unwrapped_start_offset, s );
+
+            std::string temp_line_str;
+
+            // all full lines between start and end
+            for ( int l = unwrapped_start_line + 1; l < unwrapped_end_line; l++ ) {
+                ts.getUnwrappedLine( l, 0, temp_line_str );
+
+                s += '\n';
+
+                s += temp_line_str;
+            }
+
+            // and the rest up to the end offset
+            ts.getUnwrappedLine( unwrapped_end_line, 0, unwrapped_end_offset, temp_line_str );
+
+            s += '\n';
+
+            s += temp_line_str;
+        }
+
+        _aguix->copyToClipboard( s );
+    }
+}
