@@ -1,6 +1,6 @@
 /* textview.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2008, 2010-2011 Ralf Hoffmann.
+ * Copyright (C) 2005-2008, 2010-2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -145,6 +145,8 @@ protected:
   } m_selection;
 
   Pixmap m_buffer;
+
+    std::pair< int, int > m_button_press_unwrapped_line_pos;
   
   void boxRedraw();
   void createContainer();
@@ -173,6 +175,10 @@ protected:
 
     void setVBarOffset( int offset );
     void checkForEndReached();
+
+    std::pair< int, int >  getTextPosForMousePos( int x, int y );
+
+    void copySelectionToClipboard();
 };
 
 #endif
