@@ -1,6 +1,6 @@
 /* utf8.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2006 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2006,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -57,12 +57,20 @@ bool UTF8::isValidCharacter( const char *str )
 size_t UTF8::getLenOfCharacter( const char *str )
 {
 #ifdef DISABLE_UTF8_SUPPORT
-  return 1;
+    if ( str == NULL || *str == '\0' ) return 0;
+
+    return 1;
 #else
   size_t l;
   
-  if ( getUTF8Mode() == UTF8_DISABLED )
-    return 1;
+  if ( str == NULL ) return 0;
+
+  if ( getUTF8Mode() == UTF8_DISABLED ) {
+
+      if ( *str == '\0' ) return 0;
+
+      return 1;
+  }
   
   mbstate_t mbstate;
   memset( &mbstate, 0, sizeof( mbstate ) );
@@ -96,6 +104,9 @@ int UTF8::buildCharacterLookupListMaxlen( const char *str,
   cur = 0;
   while ( *str != '\0' ) {
     l = getLenOfCharacter( str );
+
+    if ( l < 1 ) break;
+
     cur += l;
     if ( maxlen >= 0 && (int)cur > maxlen ) {
         break;
@@ -119,20 +130,16 @@ void UTF8::disableUTF8()
 
 int UTF8::movePosToNextChar( const char *str, int &pos )
 {
-  size_t l = 1;
+    size_t l;
 
-  if ( getUTF8Mode() != UTF8_DISABLED ) {
     l = getLenOfCharacter( str + pos );
     pos += l;
-  } else {
-    pos++;
-  }
-  return l;
+
+    return l;
 }
 
 int UTF8::movePosToPrevChar( const char *str, int &pos )
 {
-  if ( getUTF8Mode() != UTF8_DISABLED ) {
     int old_pos = pos;
 
     pos--;
@@ -141,10 +148,6 @@ int UTF8::movePosToPrevChar( const char *str, int &pos )
 
     if ( pos < 0 ) pos = 0;
     return old_pos - pos;
-  } else {
-    pos--;
-    return 1;
-  }
 }
 
 int UTF8::findCharacterPosition( int byte_pos, std::vector<int> &char2byte_lookup )
