@@ -1,6 +1,6 @@
 /* util.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2008,2010 Ralf Hoffmann.
+ * Copyright (C) 2001-2008,2010,2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -331,4 +331,76 @@ namespace AGUIXUtils
         return precision;
     }
 
+    void split_string( std::vector< std::string > &v,
+                       const std::string &str1,
+                       const char split_element )
+    {
+        std::string::size_type start_pos = 0;
+
+        if ( start_pos >= str1.length() ) {
+            // empty string
+            v.push_back( str1 );
+            return;
+        }
+
+        std::string::size_type next_pos = str1.find( split_element, start_pos );
+
+        if ( next_pos == std::string::npos ) {
+            // no split_element found
+            v.push_back( str1 );
+            return;
+        }
+
+        // now there is at least one split element
+
+        while ( start_pos >= 0 && start_pos < str1.length() ) {
+            next_pos = str1.find( split_element, start_pos );
+
+            int basename_length;
+
+            if ( next_pos == std::string::npos ) {
+                basename_length = str1.length() - start_pos;
+            } else {
+                basename_length = next_pos - start_pos;
+            }
+
+            std::string basename( str1, start_pos, basename_length );
+
+            v.push_back( basename );
+
+            if ( next_pos == std::string::npos ) {
+                break;
+            }
+
+            start_pos = next_pos + 1;
+        }
+
+        if ( start_pos >= str1.length() ) {
+            // ended with split_element so push empty string
+            v.push_back( "" );
+        }
+    }
+
+    bool starts_with( const std::string &str,
+                      const std::string &prefix )
+    {
+        if ( str.length() >= prefix.length() &&
+             str.compare( 0, prefix.length(), prefix ) == 0 ) {
+            return true;
+        }
+
+        return false;
+    }
+
+    bool ends_with( const std::string &str,
+                    const std::string &suffix )
+    {
+        if ( str.length() >= suffix.length() &&
+             str.compare( str.length() - suffix.length(),
+                          suffix.length(), suffix ) == 0 ) {
+            return true;
+        }
+
+        return false;
+    }
 }
