@@ -1,6 +1,6 @@
 /* util.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2008,2010 Ralf Hoffmann.
+ * Copyright (C) 2001-2008,2010,2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -26,6 +26,7 @@
 #include <string>
 #include <sstream>
 #include <stdexcept>
+#include <vector>
 
 int createLines(const char*,char ***);
 
@@ -95,6 +96,16 @@ namespace AGUIXUtils
     }
 
     int calc_precision( double v );
+
+    void split_string( std::vector< std::string > &v,
+                       const std::string &str1,
+                       const char split_element );
+
+    bool starts_with( const std::string &str,
+                      const std::string &prefix );
+
+    bool ends_with( const std::string &str,
+                    const std::string &suffix );
 }
 
 #endif
