@@ -1,6 +1,6 @@
 /* basic_actions.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2008 Ralf Hoffmann.
+ * Copyright (C) 2001-2008,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -26,6 +26,12 @@
 #include "wcfiletype.hh"
 #include "fileentry.hh"
 #include "nmspecialsourceext.hh"
+#include "worker_locale.h"
+#include "dnd.h"
+#include <aguix/button.h>
+#include <aguix/cyclebutton.h>
+#include "wconfig.h"
+#include "datei.h"
 
 /***********
   DNDAction
@@ -45,6 +51,7 @@ const char *DNDAction::getName()
 
 DNDAction::DNDAction() : FunctionProto()
 {
+    m_category = FunctionProto::CAT_FILETYPE;
 }
 
 DNDAction::~DNDAction()
@@ -195,6 +202,7 @@ const char *DoubleClickAction::getName()
 
 DoubleClickAction::DoubleClickAction() : FunctionProto()
 {
+    m_category = FunctionProto::CAT_FILETYPE;
 }
 
 DoubleClickAction::~DoubleClickAction()
@@ -370,6 +378,7 @@ const char *ShowAction::getName()
 
 ShowAction::ShowAction() : FunctionProto()
 {
+    m_category = FunctionProto::CAT_FILETYPE;
 }
 
 ShowAction::~ShowAction()
@@ -545,6 +554,7 @@ const char *RawShowAction::getName()
 
 RawShowAction::RawShowAction() : FunctionProto()
 {
+    m_category = FunctionProto::CAT_FILETYPE;
 }
 
 RawShowAction::~RawShowAction()
@@ -722,6 +732,7 @@ UserAction::UserAction() : FunctionProto()
 {
   nr=0;
   hasConfigure = true;
+  m_category = FunctionProto::CAT_FILETYPE;
 }
 
 UserAction::~UserAction()
@@ -997,6 +1008,7 @@ ChangeHiddenFlag::ChangeHiddenFlag() : FunctionProto()
 {
   mode=0;
   hasConfigure = true;
+    m_category = FunctionProto::CAT_FILELIST;
 }
 
 ChangeHiddenFlag::~ChangeHiddenFlag()
