@@ -1,6 +1,6 @@
 /* changelabelop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2008 Ralf Hoffmann.
+ * Copyright (C) 2008,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -28,6 +28,14 @@
 #include "nwc_path.hh"
 #include "nmspecialsourceext.hh"
 #include <algorithm>
+#include "fileentry.hh"
+#include "datei.h"
+#include "worker_locale.h"
+#include <aguix/choosebutton.h>
+#include <aguix/fieldlistview.h>
+#include <aguix/button.h>
+#include <aguix/stringgadget.h>
+#include "wconfig.h"
 
 const char *ChangeLabelOp::name = "ChangeLabelOp";
 
