@@ -1,6 +1,6 @@
 /* changelayoutop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2009-2010 Ralf Hoffmann.
+ * Copyright (C) 2009-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -29,14 +29,19 @@
 #include <aguix/button.h>
 #include <aguix/cyclebutton.h>
 #include <aguix/slider.h>
+#include <aguix/choosebutton.h>
+#include <aguix/fieldlistview.h>
 #include <sstream>
 #include <algorithm>
+#include "datei.h"
+#include "worker_locale.h"
 
 const char *ChangeLayoutOp::name = "ChangeLayoutOp";
 
 ChangeLayoutOp::ChangeLayoutOp() : FunctionProto()
 {
     hasConfigure = true;
+    m_category = FunctionProto::CAT_SETTINGS;
 }
 
 ChangeLayoutOp::~ChangeLayoutOp()
