@@ -1,6 +1,6 @@
 /* chmodop.c
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2008 Ralf Hoffmann.
+ * Copyright (C) 2001-2004,2008,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -24,6 +24,10 @@
 #include "normalmode.h"
 #include "worker.h"
 #include "nmspecialsourceext.hh"
+#include "datei.h"
+#include <aguix/button.h>
+#include <aguix/choosebutton.h>
+#include "worker_locale.h"
 
 const char *ChModOp::name="ChModOp";
 
@@ -34,6 +38,7 @@ ChModOp::ChModOp() : FunctionProto()
   recursive=false;
   requestflags = true;
   hasConfigure = true;
+    m_category = FunctionProto::CAT_FILEOPS;
 }
 
 ChModOp::~ChModOp()
