@@ -1,6 +1,6 @@
 /* condparser.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2004-2006,2011 Ralf Hoffmann.
+ * Copyright (C) 2004-2006,2011-2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -30,6 +30,7 @@
 #include "worker.h"
 #include "datei.h"
 #include "worker_locale.h"
+#include "nwc_path.hh"
 
 struct CondParser::deftokens CondParser::keywords[] = {
   { "lasterror", CondParser::TOK_LASTERROR },
@@ -520,7 +521,7 @@ CondParser::erg_t *CondParser::factor()
               e = (erg_t*)_allocsafe( sizeof( erg_t ) );
               ec = new ExeClass( ExeClass::EXECUTE_NORMAL );
               if ( fe != NULL ) {
-                tstr2 = ParentDir( fe->fullname, NULL );
+                tstr2 = NWC::Path::parentDir( fe->fullname, NULL );
                 if ( tstr2 != NULL ) {
                   ec->cdDir( tstr2 );
                   _freesafe( tstr2 );
@@ -1181,7 +1182,7 @@ char *CondParser::getOutput( const char *str, FileEntry *tfe )
   
   if ( tstr != NULL ) {
     ec = new ExeClass( ExeClass::EXECUTE_NORMAL );
-    tstr2 = ParentDir( fe->fullname, NULL );
+    tstr2 = NWC::Path::parentDir( fe->fullname, NULL );
     if ( tstr2 != NULL ) {
       ec->cdDir( tstr2 );
       _freesafe( tstr2 );
