@@ -118,6 +118,7 @@ struct mytoken tokenlist[]={
   {VERSION_WCP,"version"},
   {EXTERN_WCP,"extern"},
   {UPDATETIME_WCP,"updatetime"},
+  {SHOWHINTS_WCP,"showhints"},
   {PROGRAM_WCP,"program"},
   {KEY_WCP,"key"},
   {DOUBLE_WCP,"double"},
@@ -390,7 +391,10 @@ struct mytoken tokenlist[]={
   { PATHJUMPOP_WCP, "pathjumpop" },
   { PATHJUMPALLOWDIRS_WCP, "pathjumpallowdirs" },
   { CLIPBOARDOP_WCP, "clipboardop" },
-  { CLIPBOARDSTRING_WCP, "clipboardstring" }
+  { CLIPBOARDSTRING_WCP, "clipboardstring" },
+  { COMMANDSTRING_WCP, "commandstring" },
+  { EVALCOMMAND_WCP, "evalcommand" },
+  { WATCHMODE_WCP, "watchmode" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
