@@ -1,6 +1,6 @@
 /* copyop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2006,2008 Ralf Hoffmann.
+ * Copyright (C) 2001-2006,2008,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -25,6 +25,12 @@
 #include "copyop.h"
 #include "copyopwin.hh"
 #include "nmspecialsourceext.hh"
+#include "worker_locale.h"
+#include "datei.h"
+#include "dnd.h"
+#include <aguix/choosebutton.h>
+#include <aguix/cyclebutton.h>
+#include <aguix/button.h>
 
 const char *CopyOp::name="CopyOp";
 
@@ -40,6 +46,7 @@ CopyOp::CopyOp() : FunctionProto()
   fastcopy=COPYOP_NORMALCOPY;
   preserve_attr=true;
   hasConfigure = true;
+    m_category = FunctionProto::CAT_FILEOPS;
 }
 
 CopyOp::~CopyOp()
