@@ -739,6 +739,13 @@ CopyOpWin::conttimer()
     filestarttime.tv_sec++;
     filestarttime.tv_usec -= 1000000;
   }
+
+  lasttime_global.tv_sec += s;
+  lasttime_global.tv_usec += us;
+  if ( lasttime_global.tv_usec > 1000000 ) {
+      lasttime_global.tv_sec++;
+      lasttime_global.tv_usec -= 1000000;
+  }
 }
 
 int CopyOpWin::request( const char *title,
