@@ -1,6 +1,6 @@
 /* datei.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2007,2009-2010 Ralf Hoffmann.
+ * Copyright (C) 2001-2007,2009-2010,2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -26,6 +26,7 @@
 #include <aguix/mutex.h>
 #include <aguix/utf8.hh>
 #include "nwc_os.hh"
+#include "nwc_path.hh"
 
 Datei::Datei()
 {
@@ -322,102 +323,6 @@ int Datei::getString(char *buf,int count)
   return strlen(buf);
 }
 
-char *ParentDir(const char *pathstr,char *dirnamereturn)
-{
-  char *newpath;
-  int x,y;
-  x=strlen(pathstr);
-  if(x<2) {
-    newpath=(char*)_allocsafe(2);
-    strcpy(newpath,"/");
-    if(dirnamereturn!=NULL) strcpy(dirnamereturn,"");
-  } else {
-    if(pathstr[x-1]=='/') y=x-2; else y=x-1;
-    while((pathstr[y]!='/')&&(y>0)) {
-      y--;
-    }
-    if(y==0) {
-      newpath=(char*)_allocsafe(2);
-      strcpy(newpath,"/");
-      if(dirnamereturn!=NULL) strcpy(dirnamereturn,pathstr+1);
-    } else {
-      newpath=(char*)_allocsafe(y+1);
-      strncpy(newpath,pathstr,y);
-      if(dirnamereturn!=NULL) strcpy(dirnamereturn,pathstr+y+1);
-      newpath[y]=0;
-    }
-  }
-  return newpath;
-}
-
-char *HandlePath(const char *pathstr)
-{
-  char *newpath, *newpath2, *buffer;
-  int x,y;
-  int start,end;
-  int ende;
-  
-  buffer = (char*)_allocsafe( strlen( pathstr ) + 1 );
-  x=strlen(pathstr);
-  y=0;
-  ende=0;
-  newpath=(char*)_allocsafe(1);
-  newpath[0]=0;
-  do {
-    start=y;
-    while((pathstr[y]!='/')&&((y+1)<x)) {
-      y++;
-    }
-    if(((y+1)>=x)&&(pathstr[y]!='/')) end=y+1; else end=y;
-    if(end>start) {
-      strncpy(buffer,pathstr+start,end-start);
-      buffer[end-start]=0;
-      if(strcmp(buffer,".")==0) {
-        y++;
-      } else if(strcmp(buffer,"..")==0) {
-	if ( strchr( newpath, '/' )  == NULL ) {
-	  // no previous dir so keep ".."
-	  newpath2 = (char*)_allocsafe( strlen( newpath ) + 3 + 1);
-          if ( ( strlen( newpath ) > 0 ) && ( newpath[ strlen( newpath ) - 1 ] != '/' ) ) {
-	    sprintf( newpath2, "%s/..", newpath );
-	  } else {
-	    sprintf( newpath2, "%s..", newpath );
-	  }
-	  _freesafe( newpath );
-	  newpath = newpath2;
-	} else {
-	  newpath2=ParentDir(newpath,NULL);
-	  _freesafe(newpath);
-	  newpath=newpath2;
-	}
-        y++;
-      } else {
-        newpath2=(char*)_allocsafe(strlen(newpath)+1+strlen(buffer)+1);
-        strcpy(newpath2,newpath);
-        if(strlen(newpath)>0) {
-          if(newpath[strlen(newpath)-1]!='/') strcat(newpath2,"/");
-        }
-        strcat(newpath2,buffer);
-        _freesafe(newpath);
-        newpath=newpath2;
-        y++;
-      }
-    } else {
-      if(start==0) {
-        newpath2=(char*)_allocsafe(2);
-        strcpy(newpath2,"/");
-        _freesafe(newpath);
-        newpath=newpath2;
-      }
-      y++;
-    }
-    if(y>=x) ende=1;
-  } while(ende==0);
-
-  _freesafe( buffer );
-  return newpath;
-}
-
 bool Datei::fileExists(const char *name)
 {
   worker_struct_stat stbuf;
@@ -541,40 +446,6 @@ long Datei::errors()
   return e;
 }
 
-char *ParentDir(const char *pathstr,char *dirnamereturn,int returnsize)
-{
-  char *newpath;
-  int x,y;
-  x=strlen(pathstr);
-  if(x<2) {
-    newpath=(char*)_allocsafe(2);
-    strcpy(newpath,"/");
-    if(dirnamereturn!=NULL) strcpy(dirnamereturn,"");
-  } else {
-    if(pathstr[x-1]=='/') y=x-2; else y=x-1;
-    while((pathstr[y]!='/')&&(y>0)) {
-      y--;
-    }
-    if(y==0) {
-      newpath=(char*)_allocsafe(2);
-      strcpy(newpath,"/");
-      if(dirnamereturn!=NULL) {
-        strncpy(dirnamereturn,pathstr+1,returnsize);
-        dirnamereturn[returnsize-1]=0;
-      }
-    } else {
-      newpath=(char*)_allocsafe(y+1);
-      strncpy(newpath,pathstr,y);
-      if(dirnamereturn!=NULL) {
-        strncpy(dirnamereturn,pathstr+y+1,returnsize);
-        dirnamereturn[returnsize-1]=0;
-      }
-      newpath[y]=0;
-    }
-  }
-  return newpath;
-}
-
 char *Datei::getFilenameFromPath(const char*path)
 {
   char *tstr;
@@ -719,185 +590,6 @@ int Datei::putStringExt(const char *format,const char *str)
   return 0;
 }
 
-char *HandlePathExt(const char *src)
-{
-  char *tstr,*tstr2;
-  char *newpath;
-  char *buf;
-  int i,j;
-
-  newpath=dupstring("");
-  int pos=0,count;
-
-  // resolve "."
-  if ( src[0] == '.' ) {
-      if ( src[1] == 0 || src[1] == '/' ) {
-          std::string cwd = NWC::OS::getCWD();
-          _freesafe( newpath );
-          if ( src[1] == '/' ) newpath = catstring( cwd.c_str(), "/" );
-          else newpath = dupstring( cwd.c_str() );
-          pos = 2;
-      }
-  }
-  for(i=pos;i<(int)strlen(src);i++) {
-    if(src[i]=='$') {
-      // there is an env-variable to resolve
-      if(i>pos) {
-        // copy the chars before
-        buf=(char*)_allocsafe(i-pos+1);
-        strncpy(buf,src+pos,i-pos);
-        buf[i-pos]=0;
-        tstr=catstring(newpath,buf);
-        _freesafe(newpath);
-        _freesafe(buf);
-        newpath=tstr;
-      }
-      // now find the end of the env-variable
-      if(src[i+1]=='{') {
-        count=1;
-        // search for closing bracket
-        for(j=i+2;;j++) {
-          if(src[j]=='{') count++;
-          else if(src[j]==0) break;
-          else if(src[j]=='}') count--;
-          if(count==0) {
-            j++; // to point at the first char after this
-            break;
-          }
-        }
-        // j-1 is the closing bracket
-        if((j-2)>=(i+2)) {
-          tstr=dupstring(src+i+2);
-          tstr[(j-2)-(i+2)+1]=0;
-          tstr2=resolveEnv(tstr);
-          _freesafe(tstr);
-          tstr=catstring(newpath,tstr2);
-          _freesafe(newpath);
-          _freesafe(tstr2);
-          newpath=tstr;
-        }
-      } else {
-        // find the "/" or the end
-        for(j=i+1;;j++) {
-          if(src[j]==0) break;
-          else if(src[j]=='/') break;
-        }
-        // j-1 is last char for the env
-        if((j-1)>=(i+1)) {
-          tstr=dupstring(src+i+1);
-          tstr[(j-1)-(i+1)+1]=0;
-          tstr2=resolveEnv(tstr);
-          _freesafe(tstr);
-          tstr=catstring(newpath,tstr2);
-          _freesafe(newpath);
-          _freesafe(tstr2);
-          newpath=tstr;
-        }
-      }
-      pos=j;
-      i=pos;
-    }
-  }
-  if(i>pos) {
-    // copy the chars before
-    buf=(char*)_allocsafe(i-pos+1);
-    strncpy(buf,src+pos,i-pos);
-    buf[i-pos]=0;
-    tstr=catstring(newpath,buf);
-    _freesafe(newpath);
-    _freesafe(buf);
-    newpath=tstr;
-  }
-  // now resolve the normal things like ".." "." and so on
-  tstr=HandlePath(newpath);
-  _freesafe(newpath);
-  return tstr;
-}
-
-char *resolveEnv(const char* str)
-{
-  char *resstr,*tstr,*tstr2;
-  char *buf;
-  int i,j;
-
-  resstr=dupstring("");
-  int pos=0,count;
-
-  for(i=pos;i<(int)strlen(str);i++) {
-    if(str[i]=='$') {
-      // there is an env-variable to resolve
-      if(i>pos) {
-        // copy the chars before
-        buf=(char*)_allocsafe(i-pos+1);
-        strncpy(buf,str+pos,i-pos);
-        buf[i-pos]=0;
-        tstr=catstring(resstr,buf);
-        _freesafe(resstr);
-        _freesafe(buf);
-        resstr=tstr;
-      }
-      // now find the end of the env-variable
-      if(str[i+1]=='{') {
-        count=1;
-        // search for closing bracket
-        for(j=i+2;;j++) {
-          if(str[j]=='{') count++;
-          else if(str[j]==0) break;
-          else if(str[j]=='}') count--;
-          if(count==0) {
-            j++; // to point at the first char after this
-            break;
-          }
-        }
-        // j-1 is the closing bracket
-        if((j-2)>=(i+2)) {
-          tstr=dupstring(str+i+2);
-          tstr[(j-2)-(i+2)+1]=0;
-          tstr2=resolveEnv(tstr);
-          _freesafe(tstr);
-          tstr=catstring(resstr,tstr2);
-          _freesafe(resstr);
-          _freesafe(tstr2);
-          resstr=tstr;
-        }
-      } else {
-        // find the "/" or the end
-        for(j=i+1;;j++) {
-          if(str[j]==0) break;
-          else if(str[j]=='/') break;
-        }
-        // j-1 is last char for the env
-        if((j-1)>=(i+1)) {
-          tstr=dupstring(str+i+1);
-          tstr[(j-1)-(i+1)+1]=0;
-          tstr2=resolveEnv(tstr);
-          _freesafe(tstr);
-          tstr=catstring(resstr,tstr2);
-          _freesafe(resstr);
-          _freesafe(tstr2);
-          resstr=tstr;
-        }
-      }
-      pos=j;
-    }
-  }
-  if(i>pos) {
-    // copy the chars before
-    buf=(char*)_allocsafe(i-pos+1);
-    strncpy(buf,str+pos,i-pos);
-    buf[i-pos]=0;
-    tstr=catstring(resstr,buf);
-    _freesafe(resstr);
-    _freesafe(buf);
-    resstr=tstr;
-  }
-  tstr=getenv(resstr);
-  _freesafe(resstr);
-  if(tstr==NULL) resstr=dupstring("");
-  else resstr=dupstring(tstr);
-  return resstr;
-}
-
 char *Datei::shrinkFilename( const char *str, int maxlength, AWidth &lencalc )
 {
   char *tstr = NULL;
@@ -1184,12 +876,12 @@ char *Datei::getRelativePath( const char *source, const char *destdir )
      "." and removing an added "../" for ".." but this way this function
      keeps small and clean :-)
    */
-  mysource = HandlePath( source );
+  mysource = NWC::Path::handlePath( source );
   for ( i = strlen( mysource ) - 1; i >= 0; i-- ) {
     if ( mysource[i] == '/' ) mysource[i] = '\0';
     else break;
   }
-  mydestdir = HandlePath( destdir );
+  mydestdir = NWC::Path::handlePath( destdir );
   for ( i = strlen( mydestdir ) - 1; i >= 0; i-- ) {
     if ( mydestdir[i] == '/' ) mydestdir[i] = '\0';
     else break;
