@@ -1,6 +1,6 @@
 /* datei.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2008,2010-2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2008,2010-2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -110,13 +110,8 @@ private:
   int sectiondepth;
 };
 
-char *ParentDir(const char *,char *);
-char *ParentDir(const char *,char *,int);
-char *HandlePath(const char *);
-char *HandlePathExt(const char*);
 int getOwnerStringLen(uid_t,gid_t);
 char* getOwnerString(uid_t,gid_t);
-char *resolveEnv(const char*);
 
 #endif
 
