@@ -1,6 +1,6 @@
 /* dirbookmarkui.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2007-2008,2010 Ralf Hoffmann.
+ * Copyright (C) 2007-2008,2010,2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -562,8 +562,13 @@ void DirBookmarkUI::maximizeWin()
     if ( my_w < 400 ) my_w = 400;
     if ( my_h < 300 ) my_h = 300;
 
-    int mw = m_aguix.getRootWindowWidth() * 80 / 100;
-    int mh = m_aguix.getRootWindowHeight() * 80 / 100;
+    int rx, ry, rw, rh;
+
+    m_aguix.getLargestDimensionOfCurrentScreen( &rx, &ry,
+                                                &rw, &rh );
+
+    int mw = rw * 80 / 100;
+    int mh = rh * 80 / 100;
     m_co1->resize( mw, mh );
     m_co1->rearrange();
 
