@@ -1,6 +1,6 @@
 /* enterdirop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2009,2011 Ralf Hoffmann.
+ * Copyright (C) 2009,2011-2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -32,6 +32,7 @@
 #include <aguix/button.h>
 #include <aguix/stringgadget.h>
 #include "datei.h"
+#include "nwc_path.hh"
 
 /* Bei normalen Aufruf: aktiven Eintrag benutzen
    Bei DND: Element (muesste aktives sein) in Ziel (muss erst erkannt werden) darstellen
@@ -140,7 +141,7 @@ int EnterDirOp::run( WPUContext *wpu, ActionMessage *msg )
                             //TODO show a choosebutton in the requester to enable env replacing?
                             std::string tstr1 = return_str;
                             if ( tstr1[0] == '$' ) {
-                                char *tstr2 = HandlePathExt( tstr1.c_str() );
+                                char *tstr2 = NWC::Path::handlePathExt( tstr1.c_str() );
                                 tstr1 = tstr2;
                                 _freesafe( tstr2 );
                             }
