@@ -242,7 +242,6 @@ int FileEntry::writeDestination2Buf(char *buf,int size2,bool terminated)
 
 void FileEntry::setLVC( FieldListView *lv, int row, const std::vector<WorkerTypes::listcol_t> *dis )
 {
-  int mlen=0;
   char *str=NULL;
   struct tm *timeptr;
   loff_t dissize, li;
@@ -361,35 +360,29 @@ void FileEntry::setLVC( FieldListView *lv, int row, const std::vector<WorkerType
         break;
       case WorkerTypes::LISTCOL_MOD:
         timeptr = localtime( &( statbuf.lastmod ) );
-        mlen = wconfig->getDatelen( timeptr );
-        str = (char*)_allocsafe( mlen + 2 );
-        memset( str, ' ', mlen + 1 );
-        x = wconfig->writeDateToString( str , mlen + 1, timeptr );
-        str[ x ] = '\0';
-        s1 = str;
-        _freesafe( str );
+
+        s1 = "";
+
+        wconfig->writeDateToString( s1, timeptr );
+
         lv->setText( row, cur_field, s1 );
         break;
       case WorkerTypes::LISTCOL_ACC:
         timeptr = localtime( &( statbuf.lastaccess ) );
-        mlen = wconfig->getDatelen( timeptr );
-        str = (char*)_allocsafe( mlen + 2 );
-        memset( str, ' ', mlen + 1 );
-        x = wconfig->writeDateToString( str , mlen + 1, timeptr );
-        str[ x ] = '\0';
-        s1 = str;
-        _freesafe( str );
+
+        s1 = "";
+
+        wconfig->writeDateToString( s1, timeptr );
+
         lv->setText( row, cur_field, s1 );
         break;
       case WorkerTypes::LISTCOL_CHANGE:
         timeptr = localtime( &( statbuf.lastchange ) );
-        mlen = wconfig->getDatelen( timeptr );
-        str = (char*)_allocsafe( mlen + 2 );
-        memset( str, ' ', mlen + 1 );
-        x = wconfig->writeDateToString( str , mlen + 1, timeptr );
-        str[ x ] = '\0';
-        s1 = str;
-        _freesafe( str );
+
+        s1 = "";
+
+        wconfig->writeDateToString( s1, timeptr );
+
         lv->setText( row, cur_field, s1 );
         break;
       case WorkerTypes::LISTCOL_INODE:
@@ -1003,7 +996,10 @@ bool FileEntry::equals( const FileEntry &fe ) const
   if ( strcmp( fullname, fe.fullname ) != 0 ) return false;
 
   // finally require same times
-  if ( statbuf.lastaccess != fe.statbuf.lastaccess ) return false;
+
+  // skip access time check since it might be changed by background file type check
+  // if ( statbuf.lastaccess != fe.statbuf.lastaccess ) return false;
+
   if ( statbuf.lastmod != fe.statbuf.lastmod ) return false;
   if ( statbuf.lastchange != fe.statbuf.lastchange ) return false;
 
