@@ -1,6 +1,6 @@
 /* filereq.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2007,2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2007,2011-2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -34,6 +34,7 @@
 #include "fileentry.hh"
 #include "simplelist.hh"
 #include "datei.h"
+#include "nwc_path.hh"
 
 FileRequester::FileRequester(AGUIX *parent)
 {
@@ -255,7 +256,7 @@ void FileRequester::reset()
 
 void FileRequester::setDir(const char *dir)
 {
-  char *tstr=HandlePath(dir);
+  char *tstr=NWC::Path::handlePath(dir);
   int row;
   
   verz->closeDir();
@@ -376,7 +377,7 @@ int FileRequester::request_entry( const char *title,
 
   if ( actdir == NULL ) {
     if ( dir == NULL ) {
-      use_dir = HandlePathExt( "." );
+      use_dir = NWC::Path::handlePathExt( "." );
       if ( use_dir == NULL ) {
         use_dir = dupstring( "/" );
       }
@@ -592,7 +593,7 @@ int FileRequester::request_entry( const char *title,
 
 void FileRequester::setDirOneSelect( const char *dir )
 {
-  char *tstr=HandlePath( dir );
+  char *tstr=NWC::Path::handlePath( dir );
   int row;
   
   verz->closeDir();
