@@ -1,6 +1,6 @@
 /* flagreplacer.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006,2011 Ralf Hoffmann.
+ * Copyright (C) 2006,2011-2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -28,7 +28,8 @@
 #include "worker.h"
 #include "worker_locale.h"
 
-FlagReplacer::FlagReplacer( FlagProducer &flagstore ) : _flagstore( flagstore )
+FlagReplacer::FlagReplacer( FlagProducer &flagstore ) : _flagstore( flagstore ),
+                                                        m_replace_errors( 0 )
 {
 }
 
@@ -47,6 +48,8 @@ std::string FlagReplacer::replaceFlags( const std::string &str, bool quote )
 
   const char *sstr = str.c_str();
 
+  m_replace_errors = 0;
+
   //TODO utf8 improvements
   for ( ende = false; ende == false; ) {
     ch = sstr[spos++];
@@ -121,6 +124,8 @@ std::string FlagReplacer::replaceFlags( const std::string &str, bool quote )
         } else {
           dstr += replacementstr.c_str();
         }
+      } else {
+          m_replace_errors++;
       }
       mode = 0;
     }
@@ -285,3 +290,8 @@ std::string FlagReplacer::requestFlag( const FlagHelp &flags )
 
   return chosen_flag;
 }
+
+int FlagReplacer::failed_flag_replacements()
+{
+    return m_replace_errors;
+}
