@@ -195,3 +195,14 @@ FunctionProto::command_categories_t FunctionProto::getCategory() const
 {
     return m_category;
 }
+
+void ActionMessage::setEntriesToConsider( RefCount< NWC::VirtualDir > entries )
+{
+    m_entries_to_consider = entries;
+    mode = AM_MODE_SPECIFIC_ENTRIES;
+}
+
+RefCount< NWC::VirtualDir > ActionMessage::getEntriesToConsider()
+{
+    return m_entries_to_consider;
+}
