@@ -25,6 +25,7 @@
 #include "wdefines.h"
 #include <aguix/refcount.hh>
 #include <string>
+#include "nwc_virtualdir.hh"
 
 class Datei;
 class Worker;
@@ -50,10 +51,11 @@ public:
   ActionMessage( const ActionMessage &other );
   ActionMessage &operator=( const ActionMessage &other );
 
-  typedef enum {AM_MODE_NORMAL,
-                AM_MODE_ONLYACTIVE,
-                AM_MODE_DNDACTION,
-                AM_MODE_SPECIAL} am_mode_t;
+  typedef enum { AM_MODE_NORMAL,
+                 AM_MODE_ONLYACTIVE,
+                 AM_MODE_DNDACTION,
+                 AM_MODE_SPECIAL,
+                 AM_MODE_SPECIFIC_ENTRIES } am_mode_t;
   am_mode_t mode;
   Lister *startLister;
   const class DNDMsg *dndmsg;
@@ -65,10 +67,14 @@ public:
   void setFE( const class FileEntry *tfe );
   void setKeyAction( bool nv );
   bool getKeyAction() const;
+
+    void setEntriesToConsider( RefCount< NWC::VirtualDir > entries );
+    RefCount< NWC::VirtualDir > getEntriesToConsider();
 protected:
   Worker *worker;
   class FileEntry *fe;
   bool m_key_action;
+    RefCount< NWC::VirtualDir > m_entries_to_consider;
 };
 
 class FunctionProto
