@@ -1,6 +1,6 @@
 /* hw_volume.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2009 Ralf Hoffmann.
+ * Copyright (C) 2009-2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -24,13 +24,15 @@
 HWVolume::HWVolume( const std::string &udi ) : m_udi( udi ),
                                                m_mounted( false ),
                                                m_is_available( false ),
-                                               m_is_in_fstab( false )
+                                               m_is_in_fstab( false ),
+                                               m_size( 0 )
 {
 }
 
 HWVolume::HWVolume() : m_mounted( false ),
                        m_is_available( false ),
-                       m_is_in_fstab( false )
+                       m_is_in_fstab( false ),
+                       m_size( 0 )
 {
 }
 
@@ -115,8 +117,21 @@ bool HWVolume::operator!= ( const HWVolume &rhs ) const
 
 bool HWVolume::operator<( const HWVolume &rhs ) const
 {
-    if ( m_udi < rhs.m_udi ) return true;
-    if ( m_dev < rhs.m_dev ) return true;
+    if ( m_dev.length() > 0 && rhs.m_dev.length() > 0 ) {
+        return m_dev < rhs.m_dev;
+    } else if ( m_udi.length() > 0 && rhs.m_udi.length() > 0 ) {
+        return m_udi < rhs.m_udi;
+    } else {
+        if ( m_dev.length() > 0 ) {
+            if ( rhs.m_udi.length() > 0 ) {
+                return m_dev < rhs.m_udi;
+            }
+        } else if ( rhs.m_dev.length() > 0 ) {
+            if ( m_udi.length() > 0 ) {
+                return m_udi < rhs.m_dev;
+            }
+        }
+    }
     return false;
 }
 
@@ -138,3 +153,23 @@ bool HWVolume::sameDevice( const HWVolume &rhs ) const
 
     return true;
 }
+
+void HWVolume::setLabel( const std::string &nv )
+{
+    m_label = nv;
+}
+
+std::string HWVolume::getLabel() const
+{
+    return m_label;
+}
+
+void HWVolume::setSize( loff_t nv )
+{
+    m_size = nv;
+}
+
+loff_t HWVolume::getSize() const
+{
+    return m_size;
+}
