@@ -386,7 +386,7 @@ void HWVolumeManager::update( HWVolume &vol )
         }
 
         try {
-            loff_t size;
+            loff_t size = 0;
             
 #ifdef HAVE_HAL_DBUS
             size = getUint64Property( vol.getUDI().c_str(), "volume.size" );
