@@ -1,6 +1,6 @@
 /* intviewop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2006,2008 Ralf Hoffmann.
+ * Copyright (C) 2005-2006,2008,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -29,6 +29,13 @@
 #include "fileviewer.hh"
 #include "nmspecialsourceext.hh"
 #include "fileentry.hh"
+#include "worker_locale.h"
+#include "datei.h"
+#include <aguix/cyclebutton.h>
+#include <aguix/button.h>
+#include <aguix/choosebutton.h>
+#include <aguix/stringgadget.h>
+#include "dnd.h"
 
 const char *InternalViewOp::name = "InternalViewOp";
 
@@ -123,33 +130,31 @@ InternalViewOp::run( WPUContext *wpu, ActionMessage *msg )
 	  NormalMode::freeSelFiles( &extfilelist );
 	  }*/
       } else if ( _tmode == SHOW_CUSTOM_FILES ) {
-        char *tstr = wpu->parse( _tcustom_files.c_str(),
-				 a_max( EXE_STRING_LEN - 1024, 256 ),
-				 true );
-	if ( tstr != NULL ) {
-	  char **argvlist;
-	  char *unquoted_str;
-	  int n, i;
+          std::string res_str;
+          if ( wpu->parse( _tcustom_files.c_str(),
+                           res_str,
+                           a_max( EXE_STRING_LEN - 1024, 256 ),
+                           true ) == NormalMode::PARSE_SUCCESS ) {
+              char **argvlist;
+              char *unquoted_str;
+              int n, i;
 	  
-	  n = Worker_buildArgvList( tstr, &argvlist );
+              n = Worker_buildArgvList( res_str.c_str(), &argvlist );
 	  
-	  for ( i = 0; i < n; i++ ) {
-	    unquoted_str = AGUIX_unquoteString( argvlist[i] );
-	    filelist.push_back( unquoted_str );
-	    _freesafe( unquoted_str );
-	  }
+              for ( i = 0; i < n; i++ ) {
+                  unquoted_str = AGUIX_unquoteString( argvlist[i] );
+                  filelist.push_back( unquoted_str );
+                  _freesafe( unquoted_str );
+              }
 	  
-	  Worker_freeArgvList( argvlist );
-	  _freesafe( tstr );
-	}
+              Worker_freeArgvList( argvlist );
+          }
       }
     }
 
     if ( filelist.size() > 0 ) {
-      msg->getWorker()->setWaitCursor();
-      FileViewer fv;
-      fv.view( filelist );
-      msg->getWorker()->unsetWaitCursor();
+	FileViewer fv;
+	fv.view( filelist, NULL );
     }
   }
   return 0;
