@@ -1,6 +1,6 @@
 /* lister.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2005,2009,2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2005,2009,2011-2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -562,3 +562,9 @@ void Lister::setContainer( AContainer *mode_cont )
     }
     win->updateCont();
 }
+
+bool Lister::pathsChanged( const std::set< std::string > changed_paths )
+{
+    if ( activemode != NULL ) return activemode->pathsChanged( changed_paths );
+    return false;
+}
