@@ -1,6 +1,6 @@
 /* lister.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2009,2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2004,2009,2011-2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -24,6 +24,8 @@
 
 #include "wdefines.h"
 #include <aguix/message.h>
+#include <set>
+#include <string>
 
 class Worker;
 class AGUIX;
@@ -74,6 +76,7 @@ public:
   bool startdnd(DNDMsg *dm);
 
   void setContainer( AContainer *mode_cont );
+    bool pathsChanged( const std::set< std::string > changed_paths );
 private:
   Worker *parent;
   AGUIX *aguix;
