@@ -1,6 +1,6 @@
 /* normalmode.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -332,6 +332,13 @@ public:
 
     void setFlexibleMatchingMode( bool nv );
     bool getFlexibleMatchingMode() const;
+
+    void recenterTopBottom();
+
+    bool pathsChanged( const std::set< std::string > changed_paths );
+
+    void enableDirWatch();
+    void disableDirWatch();
 protected:
     /*
      * NM_specialsourceInt always stores a pointer to a FE
@@ -389,7 +396,7 @@ protected:
                        bool dir );
 
     NMFieldListViewDND *lv;
-    Button *hb[2], *parentb;
+    Button *hb[2], *parentb, *optionb;
     StringGadget *sg;
     static const char *type;
     NMCacheEntry *ce;
@@ -398,8 +405,8 @@ protected:
 #define BUFSIZE 128*1024
     void *buf;
     bool searchmodeon;
-    char *oldstr;
-    char *lastsearch;
+    std::string oldstr;
+    std::string lastsearch;
     std::list< const FileEntry* > *copy_deletefe_list;
     int sortmode;
   
@@ -418,7 +425,7 @@ protected:
                                  bool quote, std::string &return_str );
     void deselect( FileEntry *fe, int row );
     char *StringRequest( const char *sstr, class NM_externorder *extorder, int maxlen, NMExtList *entries[2] );
-    void startsearchmode();
+    void startsearchmode( bool use_previous_search = false );
     void finishsearchmode();
 
     /**
@@ -691,6 +698,9 @@ protected:
 
     std::string cleanFlexibleMatchString( const std::string &str );
 
+    void enableDirWatch( const std::string &path );
+    void setWatchMode( bool nv );
+
     bool m_flexible_matching_active;
     bool m_flexible_matching_enabled;
 
@@ -703,6 +713,30 @@ protected:
     NM_Filetype_Thread m_ft_thread;
 
     int prepareContext( class ActionMessage &amsg );
+
+    struct recenter_state {
+        recenter_state() : last_state( 0 ),
+                           last_yoffset( -1 ),
+                           last_active_row( - 1 ) {}
+
+        int last_state; // 0 == center, 1 == top, 2 == bottom
+        int last_yoffset, last_active_row;
+    } m_recenter_state;
+
+    struct dirwatcher {
+        dirwatcher() : path_watch_enabled( false ),
+                       last_update( 0 ),
+                       timer_enabled( false ),
+                       watch_mode( true ) {}
+
+        std::string watched_path;
+        bool path_watch_enabled;
+
+        time_t last_update;
+        bool timer_enabled;
+
+        bool watch_mode;
+    } m_dirwatcher;
 };
 
 #endif
