@@ -1,6 +1,6 @@
 /* normalmode_chmod.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2011 Ralf Hoffmann.
+ * Copyright (C) 2011-2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -43,7 +43,9 @@ void NormalMode::chmodf( struct NM_chmodorder *cmorder )
     }
 
     finishsearchmode();
-  
+
+    disableDirWatch();
+ 
     cmlist = new std::list<NM_specialsourceInt*>;
     switch(cmorder->source) {
         case NM_chmodorder::NM_SPECIAL:
@@ -73,6 +75,8 @@ void NormalMode::chmodf( struct NM_chmodorder *cmorder )
     delete cminfo;
     delete cmlist;
     update(false);
+
+    enableDirWatch();
 }
 
 int NormalMode::worker_changemod( const struct NM_specialsourceInt *ss1,
