@@ -1,6 +1,6 @@
 /* normalmode_chown.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2011 Ralf Hoffmann.
+ * Copyright (C) 2011-2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -40,6 +40,8 @@ void NormalMode::chownf(struct NM_chownorder *coorder)
 
     finishsearchmode();
   
+    disableDirWatch();
+  
     colist = new std::list<NM_specialsourceInt*>;
     switch ( coorder->source ) {
         case NM_chownorder::NM_SPECIAL:
@@ -72,6 +74,8 @@ void NormalMode::chownf(struct NM_chownorder *coorder)
     delete colist;
     freeOwnerRequestInfos();
     update(false);
+
+    enableDirWatch();
 }
 
 int NormalMode::worker_changeown( const struct NM_specialsourceInt *ss1,
