@@ -1,6 +1,6 @@
 /* normalmode_copy.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2011 Ralf Hoffmann.
+ * Copyright (C) 2011-2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -77,6 +77,8 @@ void NormalMode::copy( struct NM_copyorder *copyorder )
         return;
     }
   
+    disableDirWatch();
+  
     // clear the reclist so the slace doesn't block us because he is still reading
     // from disk
     ft_rec_list_clear();
@@ -101,6 +103,10 @@ void NormalMode::copy( struct NM_copyorder *copyorder )
         }
     }
     buf=_allocsafe(BUFSIZE);
+
+    if ( updatenm != this ) {
+        updatenm->disableDirWatch();
+    }
   
     if(copyorder->copymode==copyorder->NM_COPYMODE_NODATABASE) nodatabase=true;
     else nodatabase=false;
@@ -200,6 +206,33 @@ void NormalMode::copy( struct NM_copyorder *copyorder )
         cowin->set_bytes_to_copy(bytes);
         cowin->starttimer();
     }
+
+    // this is just the value from the last update, it might not be correct
+    if ( parentlister->getWorker()->PS_readSpace( copyorder->destdir ) == 0 ) {
+        loff_t free_blocks = parentlister->getWorker()->PS_getFreeSpace();
+        loff_t block_size = parentlister->getWorker()->PS_getBlocksize();
+
+        if ( block_size > 0 && ( ( (loff_t)bytes ) / block_size ) + 1 >= free_blocks ) {
+            // files will possibly not fit on target, ask to continue or cancel
+
+            std::string buttons = catalog.getLocale( 629 );
+            buttons += "|";
+            buttons += catalog.getLocale( 8 );
+
+            std::string freespaceh = parentlister->getWorker()->PS_getFreeSpaceH();
+
+            std::string text = AGUIXUtils::formatStringToString( catalog.getLocale( 992 ),
+                                                                 copyorder->destdir,
+                                                                 freespaceh.c_str() );
+
+            erg = request( cowin, catalog.getLocale( 123 ), text.c_str(), buttons.c_str() );
+
+            if ( erg != 0 ) {
+                cancel = true;
+            }
+        }
+    }
+
     // now database ready, can start copy-process
 
     copy_deletefe_list = new std::list<const FileEntry*>;
@@ -435,6 +468,11 @@ void NormalMode::copy( struct NM_copyorder *copyorder )
     if(updatenm!=NULL) updatenm->update(false);
     lv->showActive();
     aguix->Flush();
+
+    enableDirWatch();
+    if ( updatenm != this ) {
+        updatenm->enableDirWatch();
+    }
 }
 
 NormalMode::nm_newname_t NormalMode::getNewName( const FileEntry *oldfe, struct NM_copyorder *copyorder, const char *dest,
@@ -1613,7 +1651,7 @@ NormalMode::reg_copy_erg_t NormalMode::copyfile_reg( const char *sourcename,
 {
     int fdw, fdr;
     std::string text, button;
-    ssize_t readbytes, writebytes;
+    ssize_t readbytes;
     reg_copy_erg_t return_value = REG_COPY_ERROR;
     int erg;
     const char *myerrstr;
@@ -1653,11 +1691,15 @@ NormalMode::reg_copy_erg_t NormalMode::copyfile_reg( const char *sourcename,
         if ( cowin != NULL ) cowin->stoptimer();
         if ( errno == ENOSPC ) {
             text = AGUIXUtils::formatStringToString( catalog.getLocale( 545 ), destbasename, destdirname );
-            button = std::string( catalog.getLocale( 225 ) ) + "|" + catalog.getLocale( 8 );
+            button = std::string( catalog.getLocale( 225 ) ) + "|" + catalog.getLocale( 41 ) + "|" + catalog.getLocale( 8 );
             erg = request( cowin, catalog.getLocale( 347 ), text.c_str(), button.c_str() );
 
-            if ( erg == 1 ) return_value = REG_COPY_CANCEL;
-            else return_value = REG_COPY_SKIP;
+            if ( erg == 2 ) {
+                return_value = REG_COPY_CANCEL;
+            } else if ( erg == 1 ) {
+                // just try again
+                i--;
+            } else return_value = REG_COPY_SKIP;
         } else if ( errno == EACCES ) {
             if ( Datei::lfileExistsExt( destname ) != Datei::D_FE_NOFILE ) {
                 /// error
@@ -1738,43 +1780,62 @@ NormalMode::reg_copy_erg_t NormalMode::copyfile_reg( const char *sourcename,
             break;
         }
 
-        writebytes = worker_write( fdw, buf, readbytes );
-        if ( writebytes == readbytes ) {
-            if ( cowin != NULL ) {
+        ssize_t bytes_written = 0;
+
+        for ( ; bytes_written < readbytes; ) {
+            const ssize_t bytes_left_to_write = readbytes - bytes_written;
+            ssize_t writebytes;
+
+            writebytes = worker_write( fdw, ((const char *)buf) + bytes_written, bytes_left_to_write );
+
+            if ( writebytes > 0 ) {
+                bytes_written += writebytes;
+            }
+
+            if ( writebytes > 0 && cowin != NULL ) {
                 cowin->add_curbytes_copied( writebytes );
 
                 //TODO if I use dynamic buffer I should skip some updates
                 if ( cowin->redraw() != 0 )
                     return_value = REG_COPY_CANCEL;
             }
-        } else {
-            // something went wrong
-            // let the user choose to cancel or skip this file
-            // Ask to delete the incomplete destfile
-            // Attention: This method also moves files so be sure to
-            //   NOT delete the source!
-            if( ( ( writebytes >= 0 ) && ( writebytes < readbytes ) ) ||
-                ( errno == ENOSPC ) ) {
-                // ENOSPC isn't always reported so assume ENOSPC
-                text = AGUIXUtils::formatStringToString( catalog.getLocale( 545 ), destbasename, destdirname );
-                button = std::string( catalog.getLocale( 225 ) ) + "|" + catalog.getLocale( 8 );
-                erg = request( cowin, catalog.getLocale( 347 ), text.c_str(), button.c_str() );
+
+            if ( writebytes != bytes_left_to_write ) {
+                // something went wrong
+                // let the user choose to cancel or skip this file
+                // Ask to delete the incomplete destfile
+                // Attention: This method also moves files so be sure to
+                //   NOT delete the source!
+                if( ( ( writebytes >= 0 ) && ( writebytes < bytes_left_to_write ) ) ||
+                    ( errno == ENOSPC ) ) {
+                    // ENOSPC isn't always reported so assume ENOSPC
+                    text = AGUIXUtils::formatStringToString( catalog.getLocale( 545 ), destbasename, destdirname );
+                    button = std::string( catalog.getLocale( 225 ) ) + "|" + catalog.getLocale( 41 ) + "|" + catalog.getLocale( 8 );
+                    erg = request( cowin, catalog.getLocale( 347 ), text.c_str(), button.c_str() );
 	
-                if ( erg == 0 ) return_value = REG_COPY_SKIP;
-                else return_value = REG_COPY_CANCEL;
-            } else {
-                if ( writebytes < 0 ) {
-                    myerrstr = strerror( errno );
-                    text = AGUIXUtils::formatStringToString( catalog.getLocale( 526 ), destname, myerrstr );
+                    if ( erg == 0 ) {
+                        return_value = REG_COPY_SKIP;
+                    } else if ( erg == 1 ) {
+                        // try again
+                    } else {
+                        return_value = REG_COPY_CANCEL;
+                    }
                 } else {
-                    text = AGUIXUtils::formatStringToString( catalog.getLocale( 359 ), destname );
-                }
-                button = std::string( catalog.getLocale( 225 ) ) + "|" + catalog.getLocale( 8 );
-                erg = request( cowin, catalog.getLocale( 347 ), text.c_str(), button.c_str() );
+                    if ( writebytes < 0 ) {
+                        myerrstr = strerror( errno );
+                        text = AGUIXUtils::formatStringToString( catalog.getLocale( 526 ), destname, myerrstr );
+                    } else {
+                        text = AGUIXUtils::formatStringToString( catalog.getLocale( 359 ), destname );
+                    }
+                    button = std::string( catalog.getLocale( 225 ) ) + "|" + catalog.getLocale( 8 );
+                    erg = request( cowin, catalog.getLocale( 347 ), text.c_str(), button.c_str() );
 	
-                if ( erg == 0 ) return_value = REG_COPY_SKIP;
-                else return_value = REG_COPY_CANCEL;
+                    if ( erg == 0 ) return_value = REG_COPY_SKIP;
+                    else return_value = REG_COPY_CANCEL;
+                }
             }
+
+            if ( return_value == REG_COPY_CANCEL || return_value == REG_COPY_SKIP ) break;
         }
     } while ( ( return_value != REG_COPY_CANCEL ) && ( return_value != REG_COPY_SKIP ) );
 
