@@ -51,6 +51,7 @@ void NormalMode::externprog( class NM_externorder *extorder )
     oldtd = wpu->getTakeDirs();
     wpu->setRecursive( extorder->recursive );
     wpu->setTakeDirs( extorder->take_dirs );
+    wpu->setUseVirtualTempCopies( extorder->m_use_virtual_temp_copies );
 
     finishsearchmode();
 
@@ -66,11 +67,17 @@ void NormalMode::externprog( class NM_externorder *extorder )
 
         RefCount< GenericCallbackArg< void, int > > pea( NULL );
       
+        wpu->ref();
+
         if ( extorder->extstart == NM_externorder::NM_EXT_SHOW_OUTPUT_INT ) {
             tmpoutput_lnk = Datei::createTMPHardlink( tmpoutput );
             pea = new ProcessExitAction( true,
                                          tmpoutput_lnk,
-                                         parentlister->getWorker() );
+                                         parentlister->getWorker(), wpu );
+        } else {
+            pea = new ProcessExitAction( false,
+                                         "",
+                                         parentlister->getWorker(), wpu );
         }
 
         fp=new Datei();
@@ -282,6 +289,7 @@ NormalMode::parse_com_str_t NormalMode::parseComStr( const char *sstr, class NM_
     char *flagbuf;
     int flagbuf_size;
     NM_CLI_String res_cli_str( maxlen, quote );
+    const bool use_temp_copies_option = extorder->m_use_virtual_temp_copies;
 
     nm2 = NULL;
     l2 = parentlister->getWorker()->getOtherLister( parentlister );
@@ -353,15 +361,20 @@ NormalMode::parse_com_str_t NormalMode::parseComStr( const char *sstr, class NM_
                 break;
         }
         if ( mode == 3 ) {
-            const char *buf1 = NULL;
-            bool force_noquoting;
+            const char *buf1 = flagbuf;
+            bool force_noquoting = false;
+            bool force_notempfiles = false;
 
-            if ( flagbuf[0] == '-' ) {
-                force_noquoting = true;
-                buf1 = flagbuf + 1;
-            } else {
-                force_noquoting = false;
-                buf1 = flagbuf;
+            while ( true ) {
+                if ( buf1[0] == '-' ) {
+                    force_noquoting = true;
+                    buf1++;
+                } else if ( buf1[0] == '*' ) {
+                    force_notempfiles = true;
+                    buf1++;
+                } else {
+                    break;
+                }
             }
             // parse buf1
             if ( strncmp( buf1, "Rs", 2 ) == 0 ) {
@@ -553,26 +566,46 @@ NormalMode::parse_com_str_t NormalMode::parseComStr( const char *sstr, class NM_
                              ( extorder->take_dirs == false ) ) {
                             efeskip = true;
                         } else {
+                            std::string name_string;
+                            const char *name_cstring = NULL;
+
                             // this is a valid entry
-                            if ( filemode == 4 ) {
+                            if ( use_temp_copies_option == true &&
+                                 force_notempfiles == false &&
+                                 worker_islocal( efe1->getFullname( false ) ) == 0 ) {
+
                                 if ( extorder->wpu != NULL ) {
-                                    ctstr = extorder->wpu->getTempName4File( efe1->getFullname( false ) );
+                                    name_string = extorder->wpu->getTempName4File( efe1->getFullname( false ) );
+                                    if ( ! name_string.empty() ) {
+                                        name_cstring = name_string.c_str();
+                                    }
                                 } else {
-                                    ctstr = NULL;
+                                    name_cstring = NULL;
                                 }
-                            } else if ( filemode < 2 ) {
-                                ctstr = efe1->getName( noext );
                             } else {
-                                ctstr = efe1->getFullname( noext );
+                                if ( filemode == 4 ) {
+                                    if ( extorder->wpu != NULL ) {
+                                        name_string = extorder->wpu->getTempName4File( efe1->getFullname( false ) );
+                                        if ( ! name_string.empty() ) {
+                                            name_cstring = name_string.c_str();
+                                        }
+                                    } else {
+                                        name_cstring = NULL;
+                                    }
+                                } else if ( filemode < 2 ) {
+                                    name_cstring = efe1->getName( noext );
+                                } else {
+                                    name_cstring = efe1->getFullname( noext );
+                                }
                             }
 
-                            if ( ctstr != NULL ) {
+                            if ( name_cstring != NULL ) {
                                 if ( c > 0 ) {
                                     if ( ! res_cli_str.add_char( ' ' ) ) {
                                         ende = true;
                                     }
                                 }
-                                if ( ende == false && ! res_cli_str.add_str( ctstr, force_noquoting ) ) {
+                                if ( ende == false && ! res_cli_str.add_str( name_cstring, force_noquoting ) ) {
                                     ende = true;
                                 }
                             }               
@@ -775,6 +808,8 @@ NM_externorder::NM_externorder()
     wpu = NULL;
     take_dirs = false;
     dontcd = false;
+
+    m_use_virtual_temp_copies = false;
 }
 
 NM_externorder::~NM_externorder()
