@@ -1,6 +1,6 @@
 /* normalops.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2005,2010 Ralf Hoffmann.
+ * Copyright (C) 2001-2005,2010-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -25,6 +25,13 @@
 #include "worker.h"
 #include "workerinitialsettings.hh"
 #include "nwc_path.hh"
+#include "pers_string_list.hh"
+#include "worker_locale.h"
+#include <aguix/cyclebutton.h>
+#include <aguix/button.h>
+#include <aguix/stringgadget.h>
+#include <aguix/fieldlistview.h>
+#include "datei.h"
 
 /******
   ChangeListerSetOp
@@ -46,6 +53,7 @@ ChangeListerSetOp::ChangeListerSetOp() : FunctionProto()
 {
   mode=CLS_CURRENT_LISTER;
   hasConfigure = true;
+    m_category = FunctionProto::CAT_SETTINGS;
 }
 
 ChangeListerSetOp::~ChangeListerSetOp()
@@ -259,6 +267,7 @@ const char *SwitchListerOp::getName()
 
 SwitchListerOp::SwitchListerOp() : FunctionProto()
 {
+    m_category = FunctionProto::CAT_CURSOR;
 }
 
 SwitchListerOp::~SwitchListerOp()
@@ -294,10 +303,10 @@ const char *SwitchListerOp::getDescription()
 
 const char *FilterSelectOp::name="FilterSelectOp";
 int FilterSelectOp::instance_counter = 0;
-List *FilterSelectOp::filter_history = NULL;
-int FilterSelectOp::history_size = 30;
+size_t FilterSelectOp::history_size = 30;
 int FilterSelectOp::lastw = -1;
 int FilterSelectOp::lasth = -1;
+std::auto_ptr< PersistentStringList > FilterSelectOp::m_history;
 
 bool FilterSelectOp::isName(const char *str)
 {
@@ -311,33 +320,29 @@ const char *FilterSelectOp::getName()
 
 FilterSelectOp::FilterSelectOp() : FunctionProto()
 {
-  filter=(char*)_allocsafe(2);
-  strcpy(filter,"*");
-  actual_filter=(char*)_allocsafe(1);
-  actual_filter[0]=0;
+    filter = "*";
+    current_filter = "";
   
-  if ( instance_counter == 0 ) {
-    initHistory();
-  }
-  instance_counter++;
-  hasConfigure = true;
+    if ( instance_counter == 0 ) {
+        initHistory();
+    }
+    instance_counter++;
+    hasConfigure = true;
+    m_category = FunctionProto::CAT_SELECTIONS;
 }
 
 FilterSelectOp::~FilterSelectOp()
 {
-  _freesafe(filter);
-  _freesafe(actual_filter);
-  instance_counter--;
-  if ( instance_counter == 0 ) {
-    closeHistory();
-  }
+    instance_counter--;
+    if ( instance_counter == 0 ) {
+        closeHistory();
+    }
 }
 
 FilterSelectOp *FilterSelectOp::duplicate() const
 {
   FilterSelectOp *ta=new FilterSelectOp();
-  _freesafe(ta->filter);
-  ta->filter=dupstring(filter);
+  ta->filter = filter;
   return ta;
 }
 
@@ -355,7 +360,7 @@ int FilterSelectOp::run( WPUContext *wpu, ActionMessage *msg )
           /* Requester oeffnen */
           if(requestfilter()==true) {
             nm1=(NormalMode*)lm1;
-            nm1->filterselect(actual_filter,0);
+            nm1->filterselect( current_filter.c_str(), 0 );
           }
         }
       }
@@ -400,7 +405,7 @@ int FilterSelectOp::configure()
 
   ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 349 ), 1 ), 0, 0, cfix );
   sg = (StringGadget*)ac1_1->add( new StringGadget( aguix, 0, 0, 100,
-						    filter,
+						    filter.c_str(),
 						    0 ), 1, 0, cincw );
   
   AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 1 );
@@ -441,8 +446,7 @@ int FilterSelectOp::configure()
     }
   }
   if(ende==1) {
-    _freesafe(filter);
-    filter=dupstring(sg->getText());
+      filter = sg->getText();
   }
   delete win;
   return (ende==1)?0:1;
@@ -451,23 +455,18 @@ int FilterSelectOp::configure()
 bool FilterSelectOp::save(Datei *fh)
 {
   if ( fh == NULL ) return false;
-  fh->configPutPairString( "filter", filter );
+  fh->configPutPairString( "filter", filter.c_str() );
   return true;
 }
 
 bool FilterSelectOp::requestfilter()
 {
-  if ( filter_history == NULL ) return false;  // this can only happen when the stupid
-                                               // programmer calls closeHistory
-                                               // but to be sure...
-
   int w, h;
   StringGadget *sg;
   FieldListView *lv;
   AGUIX *aguix = Worker::getAGUIX();
   AWindow *win;
-  int id, row;
-  char *tstr;
+  int row;
   bool lvstill;
   int lastrow;
   const int cincw = AContainer::ACONT_MINH +
@@ -504,20 +503,19 @@ bool FilterSelectOp::requestfilter()
   lv->setDisplayFocus( true );
   lv->setAcceptFocus( true );
 
-  id = filter_history->initEnum();
-  tstr = (char*)filter_history->getFirstElement( id );
-  while ( tstr != NULL ) {
-    row = lv->insertRow( 0 );
-    lv->setText( row, 0, tstr );
-    lv->setPreColors( row, FieldListView::PRECOLOR_ONLYACTIVE );
-    tstr = (char*)filter_history->getNextElement( id );
+  std::list< std::string > cur_history = m_history->getList();
+  for ( std::list< std::string >::const_iterator it1 = cur_history.begin();
+        it1 != cur_history.end();
+        it1++ ) {
+      row = lv->insertRow( 0 );
+      lv->setText( row, 0, *it1 );
+      lv->setPreColors( row, FieldListView::PRECOLOR_ONLYACTIVE );
   }
-  filter_history->closeEnum( id );
-  lv->showRow( filter_history->size() - 1 );
+  lv->showRow( cur_history.size() - 1 );
   lv->redraw();
 
   sg=(StringGadget*)ac1_1->add( new StringGadget( aguix, 0, 0, 100,
-						  strlen(actual_filter)>0?actual_filter:filter,
+						  current_filter.empty() ? filter.c_str() : current_filter.c_str(),
 						  0 ), 0, 1, cincw );
   
   AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 3 );
@@ -572,10 +570,7 @@ bool FilterSelectOp::requestfilter()
               lv->takeFocus();
               lv->showActive();
               lastrow = lv->getActiveRow();
-              tstr = (char*)filter_history->getElementAt( filter_history->size() - 1 - lastrow );
-              if ( tstr != NULL ) {
-                sg->setText( tstr );
-              }
+              sg->setText( lv->getText( lastrow, 0 ).c_str() );
             }
             lvstill = false;
             break;
@@ -603,19 +598,15 @@ bool FilterSelectOp::requestfilter()
         else lvstill = false;
         lastrow = row;
         if ( lv->isValidRow( row ) == true ) {
-          tstr = (char*)filter_history->getElementAt( filter_history->size() - 1 - row );
-          if ( tstr != NULL ) {
-            sg->setText( tstr );
-          }
+            sg->setText( lv->getText( row, 0 ).c_str() );
         }
       }
       aguix->ReplyMessage(msg);
     }
   }
   if(ende==1) {
-    _freesafe(actual_filter);
-    actual_filter=dupstring(sg->getText());
-    addHistoryItem( actual_filter );
+      current_filter = sg->getText();
+      addHistoryItem( current_filter );
   }
   lastw = win->getWidth();
   lasth = win->getHeight();
@@ -625,95 +616,38 @@ bool FilterSelectOp::requestfilter()
 
 void FilterSelectOp::initHistory()
 {
-  if ( filter_history != NULL ) return;
-  char *tstr;
-  Datei *fp = new Datei();
-  std::string str1;
+    std::string str1;
 
-  filter_history = new List();
+    str1 = WorkerInitialSettings::getInstance().getConfigBaseDir();
+    str1 = NWC::Path::join( str1, "filterselect-history" );
 
-  str1 = WorkerInitialSettings::getInstance().getConfigBaseDir();
-  str1 = NWC::Path::join( str1, "filterselect-history" );
-
-  fp->open( str1.c_str(), "r" );
-  
-  while ( fp->isEOF() == false ) {
-      tstr = fp->getLine();
-      if ( tstr == NULL ) break;
-      if ( strlen( tstr ) > 0 ) {
-        filter_history->addElement( tstr );
-      } else {
-        _freesafe( tstr );
-      }
-  }
-  
-  fp->close();
-  delete fp;
+    m_history = std::auto_ptr< PersistentStringList >( new PersistentStringList( str1 ) );
 }
 
 void FilterSelectOp::closeHistory()
 {
-  if ( filter_history == NULL ) return;
-  char *tstr;
-  int id;
-  Datei *fp = new Datei();
-  std::string str1;
-
-  str1 = WorkerInitialSettings::getInstance().getConfigBaseDir();
-  str1 = NWC::Path::join( str1, "filterselect-history" );
-  fp->open( str1.c_str(), "w" );
-  
-  id = filter_history->initEnum();
-  tstr = (char*)filter_history->getFirstElement( id );
-  while ( tstr != NULL ) {
-    fp->putLine( tstr );
-    _freesafe( tstr );
-    filter_history->removeFirstElement();
-    tstr = (char*)filter_history->getFirstElement( id );
-  }
-  filter_history->closeEnum( id );
-  delete filter_history;
-  filter_history = NULL;
-  
-  fp->close();
-  delete fp;
+    m_history.reset();
 }
 
-void FilterSelectOp::addHistoryItem( const char *str )
+void FilterSelectOp::addHistoryItem( const std::string &str )
 {
-  char *tstr;
-  int id;
-  
-  id = filter_history->initEnum();
-  tstr = (char*)filter_history->getFirstElement( id );
-  while ( tstr != NULL ) {
-    if ( strcmp( str, tstr ) == 0 ) break;
-    tstr = (char*)filter_history->getNextElement( id );
-  }
-  filter_history->closeEnum( id );
+    if ( str.empty() ) return;
 
-  if ( tstr == NULL ) {
-    // not already in the list
-    if ( filter_history->size() >= history_size ) {
-      tstr = (char*)filter_history->getElementAt( filter_history->size() - 1 );
-      if ( tstr != NULL ) {
-        _freesafe( tstr );
-      }
-      filter_history->removeElementAt( filter_history->size() - 1 );
+    if ( m_history->contains( str ) ) {
+        m_history->removeEntry( str );
+        m_history->pushFrontEntry( str );
+    } else {
+        if ( m_history->size() >= history_size ) {
+            m_history->removeLast();
+        }
+        m_history->pushFrontEntry( str );
     }
-    filter_history->addElementAt( 0, dupstring( str ) );
-  } else {
-    // in the list so put it at the beginning
-    filter_history->removeElement( tstr );
-    filter_history->addElementAt( 0, tstr );
-  }
 }
 
 void FilterSelectOp::setFilter( const char *str )
 {
   if ( str == NULL ) return;
-  if ( filter != NULL ) _freesafe( filter );
-  filter = dupstring( str );
+  filter = str;
 }
 
 /*************
@@ -738,6 +672,7 @@ const char *FilterUnSelectOp::getName()
 
 FilterUnSelectOp::FilterUnSelectOp() : FilterSelectOp()
 {
+    m_category = FunctionProto::CAT_SELECTIONS;
 }
 
 FilterUnSelectOp::~FilterUnSelectOp()
@@ -747,8 +682,7 @@ FilterUnSelectOp::~FilterUnSelectOp()
 FilterUnSelectOp *FilterUnSelectOp::duplicate() const
 {
   FilterUnSelectOp *ta=new FilterUnSelectOp();
-  _freesafe(ta->filter);
-  ta->filter=dupstring(filter);
+  ta->filter = filter;
   return ta;
 }
 
@@ -766,7 +700,7 @@ int FilterUnSelectOp::run( WPUContext *wpu, ActionMessage *msg )
           /* Requester oeffnen */
           if(requestfilter()==true) {
             nm1=(NormalMode*)lm1;
-            nm1->filterselect(actual_filter,1);
+            nm1->filterselect( current_filter.c_str(), 1 );
           }
         }
       }
@@ -812,7 +746,7 @@ int FilterUnSelectOp::configure()
   ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 349 ), 1 ), 0, 0, cfix );
 
   sg = (StringGadget*)ac1_1->add( new StringGadget( aguix, 0, 0, 100,
-						    filter,
+						    filter.c_str(),
 						    0 ), 1, 0, cincw );
   
   AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 1 );
@@ -853,8 +787,7 @@ int FilterUnSelectOp::configure()
     }
   }
   if(ende==1) {
-    _freesafe(filter);
-    filter=dupstring(sg->getText());
+      filter = sg->getText();
   }
   delete win;
   return (ende==1)?0:1;
@@ -862,16 +795,11 @@ int FilterUnSelectOp::configure()
 
 bool FilterUnSelectOp::requestfilter()
 {
-  if ( filter_history == NULL ) return false;  // this can only happen when the stupid
-                                               // programmer calls closeHistory
-                                               // but to be sure...
-
   StringGadget *sg;
   FieldListView *lv;
   AGUIX *aguix = Worker::getAGUIX();
   AWindow *win;
-  int id, row;
-  char *tstr;
+  int row;
   bool lvstill;
   int lastrow;
   const int cincw = AContainer::ACONT_MINH +
@@ -909,20 +837,19 @@ bool FilterUnSelectOp::requestfilter()
   lv->setDisplayFocus( true );
   lv->setAcceptFocus( true );
 
-  id = filter_history->initEnum();
-  tstr = (char*)filter_history->getFirstElement( id );
-  while ( tstr != NULL ) {
-    row = lv->insertRow( 0 );
-    lv->setText( row, 0, tstr );
-    lv->setPreColors( row, FieldListView::PRECOLOR_ONLYACTIVE );
-    tstr = (char*)filter_history->getNextElement( id );
+  std::list< std::string > cur_history = m_history->getList();
+  for ( std::list< std::string >::const_iterator it1 = cur_history.begin();
+        it1 != cur_history.end();
+        it1++ ) {
+      row = lv->insertRow( 0 );
+      lv->setText( row, 0, *it1 );
+      lv->setPreColors( row, FieldListView::PRECOLOR_ONLYACTIVE );
   }
-  filter_history->closeEnum( id );
-  lv->showRow( filter_history->size() - 1 );
+  lv->showRow( cur_history.size() - 1 );
   lv->redraw();
 
   sg = (StringGadget*)ac1_1->add( new StringGadget( aguix, 0, 0, 100,
-						    strlen(actual_filter)>0?actual_filter:filter,
+                                                    current_filter.empty() ? filter.c_str() : current_filter.c_str(),
 						    0 ), 0, 1, cincw );
   
   AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 3 );
@@ -974,10 +901,7 @@ bool FilterUnSelectOp::requestfilter()
               lv->takeFocus();
               lv->showActive();
               lastrow = lv->getActiveRow();
-              tstr = (char*)filter_history->getElementAt( filter_history->size() - 1 - lastrow );
-              if ( tstr != NULL ) {
-                sg->setText( tstr );
-              }
+              sg->setText( lv->getText( lastrow, 0 ).c_str() );
             }
             lvstill = false;
             break;
@@ -1005,19 +929,15 @@ bool FilterUnSelectOp::requestfilter()
         else lvstill = false;
         lastrow = row;
         if ( lv->isValidRow( row ) == true ) {
-          tstr = (char*)filter_history->getElementAt( filter_history->size() - 1 - row );
-          if ( tstr != NULL ) {
-            sg->setText( tstr );
-          }
+            sg->setText( lv->getText( row, 0 ).c_str() );
         }
       }
       aguix->ReplyMessage(msg);
     }
   }
   if(ende==1) {
-    _freesafe(actual_filter);
-    actual_filter=dupstring(sg->getText());
-    addHistoryItem( actual_filter );
+      current_filter = sg->getText();
+      addHistoryItem( current_filter );
   }
   delete win;
   return (ende==1?true:false);
