@@ -1,6 +1,6 @@
 /* nwc_dir.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2006 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2006,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -126,47 +126,85 @@ namespace NWC
     return 0;
   }
 
+  void Dir::walkHandleEntry( FSEntry *entry, 
+                             DirWalkCallBack &dircb, WalkControlObj &cobj,
+                             const walk_t walk_mode )
+  {
+      if ( entry == NULL ) return;
+
+      Dir *direntry = dynamic_cast<Dir*>( entry );
+
+      if ( direntry != NULL ) {
+          dircb.visitEnterDir( *direntry, cobj );
+
+          if ( walk_mode != NORMAL && cobj.getMode() == WalkControlObj::NORMAL ) {
+              bool read_and_clear = false;
+
+              // if direntry exists but isn't real it means it's not read yet
+              if ( direntry->entryExists() == true &&
+                   direntry->isRealDir() == false &&
+                   walk_mode == RECURSIVE_DEMAND )
+                  read_and_clear = true;
+
+              if ( read_and_clear == true )
+                  direntry->readDir( false );
+
+              cobj = direntry->walk( dircb, walk_mode );
+
+              if ( read_and_clear == true )
+                  direntry->clearLists();
+          }
+
+          // leaveDir will be called even when aborting to allow
+          // some cleanup
+          dircb.visitLeaveDir( *direntry, cobj );
+      } else {
+          File *dateientry = dynamic_cast<File*>( entry );
+          if ( dateientry != NULL ) {
+              dircb.visit( *dateientry, cobj );
+          }
+      }
+  }
+
   Dir::WalkControlObj Dir::walk( DirWalkCallBack &dircb, walk_t walk_mode )
   {
     WalkControlObj cobj;
+    std::list< RefCount< FSEntry > > additional_entries, skip_entries;
+
+    dircb.prepareDirWalk( *this, cobj, additional_entries, skip_entries );
+
     for ( std::list<FSEntry*>::iterator it1 = _subentries.begin();
           it1 != _subentries.end() && cobj.getMode() != WalkControlObj::ABORT;
           it1++ ) {
-    
-      Dir *direntry = dynamic_cast<Dir*>( *it1 );
-      if ( direntry != NULL ) {
-        dircb.visitEnterDir( *direntry, cobj );
 
-        if ( walk_mode != NORMAL && cobj.getMode() == WalkControlObj::NORMAL ) {
-          bool read_and_clear = false;
+        bool skip = false;
 
-          // if direntry exists but isn't real it means it's not read yet
-          if ( direntry->entryExists() == true &&
-               direntry->isRealDir() == false &&
-               walk_mode == RECURSIVE_DEMAND )
-            read_and_clear = true;
-
-          if ( read_and_clear == true )
-            direntry->readDir( false );
-
-          cobj = direntry->walk( dircb, walk_mode );
-
-          if ( read_and_clear == true )
-            direntry->clearLists();
+        for ( std::list< RefCount< FSEntry > >::iterator it2 = skip_entries.begin();
+              it2 != skip_entries.end();
+              it2++ ) {
+            //TODO this is rather slow
+            if ( (*it2)->getFullname() == (*it1)->getFullname() ) {
+                skip = true;
+                break;
+            }
         }
 
-        // leaveDir will be called even when aborting to allow
-        // some cleanup
-        dircb.visitLeaveDir( *direntry, cobj );
-      } else {
-        File *dateientry = dynamic_cast<File*>( *it1 );
-        if ( dateientry != NULL ) {
-          dircb.visit( *dateientry, cobj );
+        if ( ! skip ) {
+            walkHandleEntry( *it1, dircb, cobj, walk_mode );
         }
-      }
 
-      if ( cobj.getMode() == WalkControlObj::SKIP )
-        cobj.setMode( WalkControlObj::NORMAL );
+        if ( cobj.getMode() == WalkControlObj::SKIP )
+            cobj.setMode( WalkControlObj::NORMAL );
+    }
+
+    for ( std::list< RefCount< FSEntry > >::iterator it1 = additional_entries.begin();
+          it1 != additional_entries.end() && cobj.getMode() != WalkControlObj::ABORT;
+          it1++ ) {
+
+        walkHandleEntry( it1->getVal(), dircb, cobj, walk_mode );
+
+        if ( cobj.getMode() == WalkControlObj::SKIP )
+            cobj.setMode( WalkControlObj::NORMAL );
     }
     return cobj;
   }
@@ -294,4 +332,15 @@ namespace NWC
     return _follow_symlinks;
   }
 
+  std::list< std::string> Dir::getFullnamesOfSubentries() const
+  {
+      std::list< std::string > l;
+
+      for ( std::list<FSEntry*>::const_iterator it1 = _subentries.begin();
+            it1 != _subentries.end();
+            it1++ ) {
+          l.push_back( (*it1)->getFullname() );
+      }
+      return l;
+  }
 }
