@@ -50,6 +50,8 @@ OwnOp::OwnOp() : FunctionProto()
   hasConfigure = true;
   
   dontcd = false;
+
+  m_use_virtual_temp_copies = true;
 }
 
 OwnOp::~OwnOp()
@@ -67,6 +69,7 @@ OwnOp::duplicate() const
   ta->inbackground = inbackground;
   ta->take_dirs = take_dirs;
   ta->dontcd = dontcd;
+  ta->m_use_virtual_temp_copies = m_use_virtual_temp_copies;
 
   ta->ownstart=ownstart;
 
@@ -138,6 +141,10 @@ OwnOp::save(Datei *fh)
   fh->configPutPairBool( "inbackground", inbackground );
   fh->configPutPairBool( "takedirs", take_dirs );
   fh->configPutPairBool( "dontcd", dontcd );
+
+  if ( m_use_virtual_temp_copies != true ) {
+      fh->configPutPairBool( "usevirtualtempcopies", m_use_virtual_temp_copies );
+  }
   return true;
 }
 
@@ -225,6 +232,7 @@ OwnOp::normalmodeown( ActionMessage *am )
   if(strlen(view_str)>0) extorder.view_str=view_str;
 
   extorder.dontcd = dontcd;
+  extorder.m_use_virtual_temp_copies = m_use_virtual_temp_copies;
 
   nm1->externprog(&extorder);
 
@@ -272,7 +280,7 @@ OwnOp::configure()
   win->create();
   _freesafe(tstr);
 
-  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 9 ), true );
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 10 ), true );
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
@@ -288,6 +296,9 @@ OwnOp::configure()
   dcdcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( dontcd == true ) ? 1 : 0,
 						     catalog.getLocale( 617 ), LABEL_RIGHT, 1, 0 ), 0, 3, cincwnr );
 
+  ChooseButton* virtualcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( m_use_virtual_temp_copies == true ) ? 1 : 0,
+                                                                       catalog.getLocale( 964 ), LABEL_RIGHT, 1, 0 ), 0, 4, cincwnr );
+
   ibcb = (ChooseButton*)ac1->add( new ChooseButton( aguix,
                                                     0,
                                                     0,
@@ -295,9 +306,9 @@ OwnOp::configure()
                                                     catalog.getLocale( 435 ),
                                                     LABEL_RIGHT,
                                                     1,
-                                                    0 ), 0, 4, cincwnr );
+                                                    0 ), 0, 5, cincwnr );
 
-  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 5 );
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 6 );
   ac1_1->setMinSpace( 5 );
   ac1_1->setMaxSpace( 5 );
   ac1_1->setBorderWidth( 0 );
@@ -329,7 +340,7 @@ OwnOp::configure()
       break;
   }
   
-  AContainer *ac1_2 = ac1->add( new AContainer( win, 5, 1 ), 0, 6 );
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 5, 1 ), 0, 7 );
   ac1_2->setMinSpace( 0 );
   ac1_2->setMaxSpace( 0 );
   ac1_2->setBorderWidth( 0 );
@@ -344,7 +355,7 @@ OwnOp::configure()
   
   fb = (Button*)ac1_2->add( new Button( aguix, 0, 0, "O", 1, 0, 0 ), 4, 0, cfix );
   
-  AContainer *ac1_3 = ac1->add( new AContainer( win, 4, 1 ), 0, 7 );
+  AContainer *ac1_3 = ac1->add( new AContainer( win, 4, 1 ), 0, 8 );
   ac1_3->setMinSpace( 0 );
   ac1_3->setMaxSpace( 0 );
   ac1_3->setBorderWidth( 0 );
@@ -365,7 +376,7 @@ OwnOp::configure()
       view_text->hide();
   }
   
-  AContainer *ac1_4 = ac1->add( new AContainer( win, 2, 1 ), 0, 8 );
+  AContainer *ac1_4 = ac1->add( new AContainer( win, 2, 1 ), 0, 9 );
   ac1_4->setMinSpace( 5 );
   ac1_4->setMaxSpace( -1 );
   ac1_4->setBorderWidth( 0 );
@@ -515,6 +526,7 @@ OwnOp::configure()
     recursive = rcb->getState();
     take_dirs = tdcb->getState();
     dontcd = dcdcb->getState();
+    m_use_virtual_temp_copies = virtualcb->getState();
     inbackground = ibcb->getState();
     _freesafe(com_str);
     _freesafe(view_str);
@@ -696,3 +708,8 @@ void OwnOp::setDontCD( bool nv )
 {
   dontcd = nv;
 }
+
+void OwnOp::setUseVirtualTempCopies( bool nv )
+{
+    m_use_virtual_temp_copies = nv;
+}
