@@ -110,6 +110,8 @@ public:
   void setInBackground( bool );
   void setTakeDirs( bool );
   void setDontCD( bool );
+    void setUseVirtualTempCopies( bool nv );
+
   static char *getFlag();
   static const char *name;
 protected:
@@ -128,6 +130,8 @@ protected:
   // temp variables
   Lister *startlister,*endlister;
   class WPUContext *use_wpu;
+
+    bool m_use_virtual_temp_copies;
   
   int normalmodeown( ActionMessage *am );
 };
