@@ -75,6 +75,10 @@ ParentActionOp::run( WPUContext *wpu, ActionMessage *msg )
       
       // but currently I do it anyway
       amsg2.setFE( msg->getFE() );
+
+      if ( msg->mode == ActionMessage::AM_MODE_SPECIFIC_ENTRIES ) {
+          amsg2.setEntriesToConsider( msg->getEntriesToConsider() );
+      }
       
       amsg2.filetype = ft;
       amsg2.m_action_descr = msg->m_action_descr;
