@@ -28,6 +28,7 @@
 #include <aguix/solidbutton.h>
 #include <aguix/util.h>
 #include <aguix/choosebutton.h>
+#include <aguix/cyclebutton.h>
 #include "worker_locale.h"
 #include "nwc_path.hh"
 #include <algorithm>
@@ -42,9 +43,12 @@
 
 PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker )
   : m_aguix( aguix ),
+    m_worker( worker ),
     m_path_store( path_store ),
     m_current_depth( -1 ),
-    m_show_hidden_entries( false )
+    m_show_hidden_entries( false ),
+    m_entry_filter_mode( SHOW_ALL ),
+    m_lv_dirty( false)
 {
     std::list< std::string > paths = m_path_store.getPaths();
     int max_path_components = 0;
@@ -54,11 +58,15 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
 
     paths.sort();
 
+    DeepPathStore temp_store_paths;
+
     for ( std::list< std::string >::const_iterator it1 = paths.begin();
           it1 != paths.end();
           it1++ ) {
         m_entries.push_back( pathjump_entry( PATH_SHOW, -1, *it1 ) );
 
+        temp_store_paths.storePath( *it1 );
+
         int slashes = std::count( it1->begin(),
                                   it1->end(),
                                   '/' );
@@ -68,22 +76,36 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
         }
     }
 
-    // currently it will not be checked if there are entries in both
-    // groups (visited paths and bookmarks+persistent paths since only
-    // one group is shown at once
-
     DeepPathStore temp_store;
 
     for ( std::list< std::string >::const_iterator it1 = m_bookmarks.begin();
           it1 != m_bookmarks.end();
           it1++ ) {
-        temp_store.storePath( *it1 );
+        //TODO it would be slightly faster to check if path is already
+        //     stored in temp_store_paths but there is no
+        //     corresponding function at the moment
+        bool changed = false;
+
+        temp_store_paths.storePath( *it1, &changed );
+
+        if ( changed ) {
+            temp_store.storePath( *it1 );
+        }
     }
 
     for ( std::list< std::string >::const_iterator it1 = pers_paths.begin();
           it1 != pers_paths.end();
           it1++ ) {
-        temp_store.storePath( *it1 );
+        //TODO it would be slightly faster to check if path is already
+        //     stored in temp_store_paths but there is no
+        //     corresponding function at the moment
+        bool changed = false;
+
+        temp_store_paths.storePath( *it1, &changed );
+
+        if ( changed ) {
+            temp_store.storePath( *it1 );
+        }
     }
 
     std::list< std::string > temp_paths = temp_store.getPaths();
@@ -102,13 +124,17 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
         }
     }
 
+    // without leading slash there could be this many components,
+    // add one for the initial slash
+    max_path_components++;
+
     m_win = std::auto_ptr<AWindow>( new AWindow( &m_aguix,
                                                  0, 0,
                                                  400, 400,
                                                  0, catalog.getLocaleCom( 60 ) ) );
     m_win->create();
 
-    m_co1 = m_win->setContainer( new AContainer( m_win.get(), 1, 5 ), true );
+    m_co1 = m_win->setContainer( new AContainer( m_win.get(), 1, 6 ), true );
     m_co1->setMaxSpace( 5 );
     
     AContainer *co1_2 = m_co1->add( new AContainer( m_win.get(), 2, 1 ), 0, 0 );
@@ -119,13 +145,30 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
     m_infixtext = static_cast<Text*>( co1_2->add( new Text( &m_aguix, 0, 0, "", 1 ),
                                                   1, 0, AContainer::CO_INCW ) );
 
+
+    AContainer *co1_4 = m_co1->add( new AContainer( m_win.get(), 2, 1 ), 0, 1 );
+    co1_4->setMaxSpace( 5 );
+    co1_4->setBorderWidth( 0 );
+    co1_4->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 980 ), 1 ),
+                0, 0, AContainer::CO_FIX );
+    m_filter_mode_cyb = (CycleButton*)co1_4->add( new CycleButton( &m_aguix, 0, 0, 50, 1, 0, 0 ),
+                                                  1, 0, AContainer::CO_INCWNR );
+
+    m_filter_mode_cyb->addOption( catalog.getLocale( 981 ) );
+    m_filter_mode_cyb->addOption( catalog.getLocale( 982 ) );
+    m_filter_mode_cyb->addOption( catalog.getLocale( 983 ) );
+
+    m_filter_mode_cyb->resize( m_filter_mode_cyb->getMaxSize(),
+                               m_filter_mode_cyb->getHeight() );
+    co1_4->readLimits();
+
     m_show_all_cb = (ChooseButton*)m_co1->add( new ChooseButton( &m_aguix, 0, 0,
                                                                  false,
                                                                  catalog.getLocale( 977 ),
                                                                  LABEL_RIGHT, 1, 0 ),
-                                               0, 1, AContainer::CO_INCWNR );
+                                               0, 2, AContainer::CO_INCWNR );
 
-    m_breadcrumb_co = m_co1->add( new AContainer( m_win.get(), max_path_components + 1, 1 ), 0, 2 );
+    m_breadcrumb_co = m_co1->add( new AContainer( m_win.get(), max_path_components + 1, 1 ), 0, 3 );
     m_breadcrumb_co->setMaxSpace( 5 );
 
     for ( int i = 0; i < max_path_components; i++ ) {
@@ -144,7 +187,7 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
     m_lv = static_cast<FieldListView*>( m_co1->add( new FieldListView( &m_aguix, 
                                                                      0, 0, 
                                                                      400, 300, 0 ),
-                                                  0, 3, AContainer::CO_MIN ) );
+                                                  0, 4, AContainer::CO_MIN ) );
     m_lv->setNrOfFields( 2 );
     m_lv->setShowHeader( true );
     m_lv->setFieldText( 1, catalog.getLocale( 809 ) );
@@ -155,7 +198,7 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
     m_lv->setFieldText( 0, catalog.getLocale( 978 ) );
     m_lv->setGlobalFieldSpace( 5 );
 
-    AContainer *co1_3 = m_co1->add( new AContainer( m_win.get(), 2, 1 ), 0, 4 );
+    AContainer *co1_3 = m_co1->add( new AContainer( m_win.get(), 3, 1 ), 0, 5 );
     co1_3->setMinSpace( 5 );
     co1_3->setMaxSpace( -1 );
     co1_3->setBorderWidth( 0 );
@@ -166,13 +209,20 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
                                              1,
                                              0,
                                              0 ), 0, 0, AContainer::CO_FIX );
+    m_cleanupb = (Button*)co1_3->add( new Button( &m_aguix,
+                                                  0,
+                                                  0,
+                                                  catalog.getLocale( 984 ),
+                                                  1,
+                                                  0,
+                                             0 ), 1, 0, AContainer::CO_FIX );
     m_cancelb = (Button*)co1_3->add( new Button( &m_aguix,
                                                  0,
                                                  0,
                                                  catalog.getLocale( 633 ),
                                                  1,
                                                  0,
-                                                 0 ), 1, 0, AContainer::CO_FIX );
+                                                 0 ), 2, 0, AContainer::CO_FIX );
 
     m_win->contMaximize( true );
     m_win->setDoTabCycling( true );
@@ -195,9 +245,11 @@ PathJumpUI::~PathJumpUI()
 
 int PathJumpUI::mainLoop()
 {
+    m_lv_dirty = true;
+
     showData();
 
-    highlight_best_hit( m_dirname + "*" );
+    highlight_best_hit( m_dirname );
 
     maximizeWin();
     m_win->show();
@@ -217,6 +269,9 @@ int PathJumpUI::mainLoop()
               case AG_BUTTONCLICKED:
                   if ( msg->button.button == m_okb ) {
                       endmode = 1;
+                  } else if ( msg->button.button == m_cleanupb ) {
+                      cleanup();
+                      endmode = -1;
                   } else if ( msg->button.button == m_cancelb ) {
                       endmode = -1;
                   } else {
@@ -251,10 +306,20 @@ int PathJumpUI::mainLoop()
                   } else if ( msg->key.key == XK_Left ) {
                       if ( ! m_current_components.empty() ) {
                           if ( m_current_depth < 0 ) {
-                              m_current_depth = m_current_components.size() - 1;
-                              update_breadcrumb();
+                              m_current_depth = m_current_components.size();
                           } else if ( m_current_depth > 0 ) {
+                              if ( m_current_depth > (int)m_current_components.size() &&
+                                   m_current_components.size() >= 1 ) {
+                                  m_current_depth = m_current_components.size();
+                              }
+
                               m_current_depth--;
+                          }
+
+                          if ( m_entry_filter_mode != SHOW_ALL ) {
+                              post_filtering();
+                              showData();
+                          } else {
                               update_breadcrumb();
                           }
                       }
@@ -262,9 +327,14 @@ int PathJumpUI::mainLoop()
                       if ( ! m_current_components.empty() ) {
                           if ( m_current_depth < 0 ) {
                               m_current_depth = 0;
-                              update_breadcrumb();
-                          } else if ( m_current_depth < (int)( m_current_components.size() - 1 ) ) {
+                          } else if ( m_current_depth <= (int)( m_current_components.size() - 1 ) ) {
                               m_current_depth++;
+                          }
+
+                          if ( m_entry_filter_mode != SHOW_ALL ) {
+                              post_filtering();
+                              showData();
+                          } else {
                               update_breadcrumb();
                           }
                       }
@@ -281,7 +351,7 @@ int PathJumpUI::mainLoop()
                   } else if ( msg->key.key == XK_End ) {
                       // key is grabbed by listview so it has no effect at the moment
                       if ( ! m_current_components.empty() ) {
-                          m_current_depth = m_current_components.size() - 1;
+                          m_current_depth = m_current_components.size();
                           update_breadcrumb();
                       }
                   } else if ( IsModifierKey( msg->key.key ) ||
@@ -297,15 +367,32 @@ int PathJumpUI::mainLoop()
                           m_show_all_cb->setState( m_show_hidden_entries );
                           apply_filter( m_filter );
                           showData();
+                      } else if ( msg->key.key == XK_f &&
+                           KEYSTATEMASK( msg->key.keystate ) == ControlMask ) {
+                          switch ( m_entry_filter_mode ) {
+                              case SHOW_ONLY_SUBDIRS:
+                                  m_entry_filter_mode = SHOW_ONLY_DIRECT_SUBDIRS;
+                                  m_filter_mode_cyb->setOption( 2 );
+                                  break;
+                              case SHOW_ONLY_DIRECT_SUBDIRS:
+                                  m_entry_filter_mode = SHOW_ALL;
+                                  m_filter_mode_cyb->setOption( 0 );
+                                  break;
+                              default:
+                                  m_entry_filter_mode = SHOW_ONLY_SUBDIRS;
+                                  m_filter_mode_cyb->setOption( 1 );
+                                  break;
+                          }
+                          apply_filter( m_filter );
+                          showData();
                       } else {
                           std::string cur_infix = m_filter;
                           cur_infix += msg->key.keybuf;
                           if ( apply_filter( cur_infix ) > 0 ) {
                               m_filter = cur_infix;
-                          } else {
                               apply_filter( m_filter );
+                              showData();
                           }
-                          showData();
                       }
                   }
                   break;
@@ -318,7 +405,12 @@ int PathJumpUI::mainLoop()
                 case AG_FIELDLV_ONESELECT:
                 case AG_FIELDLV_MULTISELECT:
                     if ( msg->fieldlv.lv == m_lv ) {
-                        update_breadcrumb( m_filter );
+                        try {
+                            m_current_entry = m_entry_fullnames.at( m_lv->getActiveRow() );
+                            set_entry( m_current_entry );
+                            showData();
+                        } catch (...) {
+                        }
                     }
                     break;
                 case AG_CHOOSECLICKED:
@@ -328,6 +420,23 @@ int PathJumpUI::mainLoop()
                         showData();
                     }
                     break;
+                case AG_CYCLEBUTTONCLICKED:
+                    if ( msg->cyclebutton.cyclebutton == m_filter_mode_cyb ) {
+                        switch ( msg->cyclebutton.option ) {
+                            case 1:
+                                m_entry_filter_mode = SHOW_ONLY_SUBDIRS;
+                                break;
+                            case 2:
+                                m_entry_filter_mode = SHOW_ONLY_DIRECT_SUBDIRS;
+                                break;
+                            default:
+                                m_entry_filter_mode = SHOW_ALL;
+                                break;
+                        }
+                        apply_filter( m_filter );
+                        showData();
+                    }
+                    break;
             }
             m_aguix.ReplyMessage( msg );
         }
@@ -338,11 +447,15 @@ int PathJumpUI::mainLoop()
     if ( endmode == 1 ) {
         std::string res = "";
 
-        for ( unsigned int i = 0; i < m_current_components.size(); i++ ) {
-            if ( m_current_depth >= 0 && (int)i > m_current_depth ) break;
+        if ( m_current_depth <= 0 ) {
+            res = "/";
+        } else {
+            for ( unsigned int i = 0; i < m_current_components.size(); i++ ) {
+                if ( (int)i >= m_current_depth ) break;
 
-            res += "/";
-            res += m_current_components[i];
+                res += "/";
+                res += m_current_components[i];
+            }
         }
 
         m_selected_path = res;
@@ -372,82 +485,91 @@ void PathJumpUI::showData()
 {
     m_infixtext->setText( m_filter.c_str() );
 
-    int current_row = m_lv->getActiveRow();
-    std::string current_path;
+    if ( m_lv_dirty ||
+         m_entry_filter_mode == SHOW_ONLY_DIRECT_SUBDIRS ) {
 
-    if ( m_lv->isValidRow( current_row ) ) {
-        current_path = m_lv->getText( current_row, 1 );
-    }
-
-    std::string best_hit;
-
-    if ( ! m_filter.empty() ) {
-        best_hit = m_pdb->getBestHit( m_filter );
-    }
-
-    m_lv->setSize( 0 );
+        m_lv->setSize( 0 );
+        m_entry_fullnames.resize( 0 );
     
-    int size = 0;
-    bool best_hit_found = false;
+        int size = 0, pos = 0;
 
-    for ( std::list< pathjump_entry >::const_iterator it1 = m_entries.begin();
-          it1 != m_entries.end();
-          it1++ ) {
-        if ( it1->m_type == PATH_SHOW ||
-             it1->m_type == BOOKMARK_SHOW ) {
-            int row = m_lv->addRow();
+        std::string prefix_filter;
 
-            m_lv->setText( row, 1, it1->m_path );
+        if ( m_entry_filter_mode == SHOW_ONLY_SUBDIRS ||
+             m_entry_filter_mode == SHOW_ONLY_DIRECT_SUBDIRS ) {
+            int i = 0;
 
-            if ( it1->m_blockcount >= 0 && ! m_filter.empty() ) {
-                std::string qual = AGUIXUtils::formatStringToString( "%3.0f%%",
-                                                                     100.0 / (double)( it1->m_blockcount + 1 ) );
-                m_lv->setText( row, 0, qual );
-            }
-
-            m_lv->setPreColors( row, FieldListView::PRECOLOR_ONLYACTIVE );
-
-            if ( ! best_hit_found &&
-                 ! best_hit.empty() &&
-                 AGUIXUtils::starts_with( it1->m_path, best_hit ) ) {
-                m_lv->setActiveRow( row );
-                best_hit_found = true;
-            }
-
-            size++;
-        }
-    }
-
-    if ( ! best_hit_found ) {
-        for ( int row = 0; row < m_lv->getElements(); row++ ) {
-            if ( AGUIXUtils::starts_with( m_lv->getText( row, 1 ),
-                                          current_path ) ) {
-                m_lv->setActiveRow( row );
-                break;
+            if ( m_current_depth > 0 ) {
+                for ( std::vector< std::string >::const_iterator it1 = m_current_components.begin();
+                      it1 != m_current_components.end();
+                      it1++, i++ ) {
+                    prefix_filter += "/";
+                    prefix_filter += *it1;
+                    if ( i + 1 >= m_current_depth ) break;
+                }
             }
         }
-    }
 
-    if ( m_lv->isValidRow( m_lv->getActiveRow() ) == false ) {
-        if ( m_lv->isValidRow( current_row ) ) {
-            m_lv->setActiveRow( current_row );
-        } else if ( current_row < 0 ) {
-            m_lv->setActiveRow( 0 );
-        } else {
-            m_lv->setActiveRow( size - 1 );
+        size_t l = prefix_filter.length();
+        bool current_entry_found = false;
+
+        for ( std::list< pathjump_entry >::const_iterator it1 = m_entries.begin();
+              it1 != m_entries.end();
+              it1++, pos++ ) {
+            if ( ( it1->m_type == PATH_SHOW ||
+                   it1->m_type == BOOKMARK_SHOW ) &&
+                 it1->m_post_filtering ) {
+                int row = m_lv->addRow();
+
+                m_entry_fullnames.push_back( it1->m_path );
+
+                if ( m_entry_filter_mode == SHOW_ONLY_DIRECT_SUBDIRS ) {
+                    size_t p2 = it1->m_path.find( '/', l + 1 );
+                    if ( p2 != std::string::npos ) {
+                        std::string s( it1->m_path, 0, p2 );
+
+                        m_lv->setText( row, 1, s );
+                    } else {
+                        m_lv->setText( row, 1, it1->m_path );
+                    }
+                } else {
+                    m_lv->setText( row, 1, it1->m_path );
+                }
+
+                if ( it1->m_blockcount >= 0 && ! m_filter.empty() ) {
+                    std::string qual = AGUIXUtils::formatStringToString( "%3.0f%%",
+                                                                         100.0 / (double)( it1->m_blockcount + 1 ) );
+                    m_lv->setText( row, 0, qual );
+                }
+
+                m_lv->setPreColors( row, FieldListView::PRECOLOR_ONLYACTIVE );
+
+                if ( m_current_entry == it1->m_path ) {
+                    m_lv->setActiveRow( row );
+                    current_entry_found = true;
+                }
+
+                size++;
+            }
         }
+
+        if ( ! current_entry_found ) {
+            for ( int row = 0; row < m_lv->getElements(); row++ ) {
+                if ( AGUIXUtils::starts_with( m_current_entry,
+                                              m_lv->getText( row, 1 ) ) ) {
+                    m_lv->setActiveRow( row );
+                    break;
+                }
+            }
+        }
+
+        m_lv->showActive();
+        m_lv->redraw();
     }
 
-    m_lv->showActive();
-    m_lv->redraw();
+    update_breadcrumb();
 
-    if ( best_hit_found ) {
-        std::string f = best_hit;
-        f += "*";
-        update_breadcrumb( f );
-    } else {
-        update_breadcrumb( m_filter );
-    }
+    m_lv_dirty = false;
 }
 
 std::string PathJumpUI::getSelectedPath()
@@ -475,67 +597,34 @@ void PathJumpUI::maximizeWin()
     if ( my_w < 400 ) my_w = 400;
     if ( my_h < 300 ) my_h = 300;
 
-    int mw = m_aguix.getRootWindowWidth() * 80 / 100;
-    int mh = m_aguix.getRootWindowHeight() * 80 / 100;
+    int rx, ry, rw, rh;
+
+    m_aguix.getLargestDimensionOfCurrentScreen( &rx, &ry,
+                                                &rw, &rh );
+
+    int mw = rw * 80 / 100;
+    int mh = rh * 80 / 100;
     m_co1->resize( mw, mh );
     m_co1->rearrange();
 
     if ( my_w < m_lv->getWidth() ) {
-        m_co1->setMinWidth( my_w, 0, 3 );
+        m_co1->setMinWidth( my_w, 0, 4 );
     } else {
-        m_co1->setMinWidth( m_lv->getWidth(), 0, 3 );
+        m_co1->setMinWidth( m_lv->getWidth(), 0, 4 );
     }
     if ( my_h < m_lv->getHeight() ) {
-        m_co1->setMinHeight( my_h, 0, 3 );
+        m_co1->setMinHeight( my_h, 0, 4 );
     } else {
-        m_co1->setMinHeight( m_lv->getHeight(), 0, 3 );
+        m_co1->setMinHeight( m_lv->getHeight(), 0, 4 );
     }
     m_win->contMaximize( true );
 }
 
 void PathJumpUI::highlight_best_hit( const std::string &filter )
 {
-    StringMatcherFNMatch matcher;
-    int matches = 0;
+    find_entry( filter, "" );
 
-    matcher.setMatchString( filter );
-    matcher.setMatchCaseSensitive( false );
-
-    for ( int i = 0; i < m_lv->getElements(); i++ ) {
-        if ( matcher.match( m_lv->getText( i, 1 ) ) ) {
-            m_lv->setActiveRow( i );
-	    m_lv->showActive();
-            matches++;
-            break;
-        }
-    }
-
-    if ( ! matches ) {
-        std::string flexible_filter;
-
-        if ( ! filter.empty() && filter[0] == '*' ) {
-            flexible_filter = "*";
-        }
-
-        flexible_filter += StringMatcherFNMatch::convertMatchStringToFlexibleMatch( filter ) + "*";
-
-        matcher.setMatchString( flexible_filter );
-        matcher.setMatchCaseSensitive( false );
-
-        for ( int i = 0; i < m_lv->getElements(); i++ ) {
-            if ( matcher.match( m_lv->getText( i, 1 ) ) ) {
-                m_lv->setActiveRow( i );
-                m_lv->showActive();
-                matches++;
-                break;
-            }
-        }
-    }
-
-    if ( m_lv->isValidRow( m_lv->getActiveRow() ) == true ) {
-        update_breadcrumb( m_lv->getText( m_lv->getActiveRow(), 1 ),
-                           filter );
-    }
+    showData();
 }
 
 int PathJumpUI::apply_filter( const std::string &filter )
@@ -562,10 +651,12 @@ int PathJumpUI::apply_filter( const std::string &filter )
 
     int exact_path_matches = 0, exact_bookmark_matches = 0,
         path_matches = 0, bookmark_matches = 0;
+    bool prefer_exact_matches = false;
 
     for ( std::list< pathjump_entry >::iterator it1 = m_entries.begin();
           it1 != m_entries.end();
           it1++ ) {
+
         if ( use_flexible ) {
             it1->m_blockcount = flmatch.countNonMatchingBlocks( it1->m_path );
         } else {
@@ -599,7 +690,8 @@ int PathJumpUI::apply_filter( const std::string &filter )
         if ( it1->m_type == PATH_SHOW ||
              it1->m_type == PATH_HIDE ) {
             if ( it1->m_blockcount == 0 ||
-                 ( it1->m_blockcount > 0 && exact_path_matches == 0 ) ) {
+                 ( it1->m_blockcount > 0 &&
+                   ( ! prefer_exact_matches || ( prefer_exact_matches && exact_path_matches == 0 ) ) ) ) {
                 it1->m_type = PATH_SHOW;
                 matches++;
             } else {
@@ -609,7 +701,8 @@ int PathJumpUI::apply_filter( const std::string &filter )
             if ( ( path_matches == 0 && ! filter.empty() ) ||
                  m_show_hidden_entries == true ) {
                 if ( it1->m_blockcount == 0 ||
-                     ( it1->m_blockcount > 0 && exact_bookmark_matches == 0 ) ) {
+                     ( it1->m_blockcount > 0 &&
+                       ( ! prefer_exact_matches || ( prefer_exact_matches && exact_bookmark_matches == 0 ) ) ) ) {
                     it1->m_type = BOOKMARK_SHOW;
                     matches++;
                 } else {
@@ -621,68 +714,237 @@ int PathJumpUI::apply_filter( const std::string &filter )
         }
     }
 
+    find_entry( m_current_entry, filter );
+
+    m_lv_dirty = true;
+
     return matches;
 }
 
-int PathJumpUI::update_breadcrumb( const std::string &path,
-                                   const std::string &highlight_filter )
+int PathJumpUI::find_entry( const std::string &name, const std::string &filter )
 {
-    std::vector< std::string > components;
-    StringMatcherFNMatch matcher;
+    std::string entry_to_find;
+    bool first_found = false;
+    std::string best_hit;
 
-    m_current_components.clear();
-
-    AGUIXUtils::split_string( components, path, '/' );
-
-    if ( components.size() > m_breadcrumb_buttons.size() ) {
-        // something wrong here, shouldn't happen
-        return 1;
+    if ( ! filter.empty() ) {
+        best_hit = entry_to_find = m_pdb->getBestHit( filter );
     }
 
-    if ( ! highlight_filter.empty() ) {
-        matcher.setMatchString( highlight_filter );
-        matcher.setMatchCaseSensitive( false );
-        m_current_depth = -1;
+    if ( entry_to_find.empty() ) {
+        entry_to_find = name;
+    }
 
-        if ( ! matcher.match( path ) ) {
-            std::string flexible_filter;
+    for ( std::list< pathjump_entry >::iterator it1 = m_entries.begin();
+          it1 != m_entries.end();
+          it1++ ) {
+        if ( it1->m_type == PATH_SHOW ||
+             it1->m_type == BOOKMARK_SHOW ) {
+            if ( AGUIXUtils::starts_with( it1->m_path,
+                                          entry_to_find ) ||
+                 first_found == false ) {
+                m_current_entry = it1->m_path;
 
-            if ( ! highlight_filter.empty() && highlight_filter[0] == '*' ) {
-                flexible_filter = "*";
+                if ( first_found ) {
+                    break;
+                } else {
+                    first_found = true;
+                }
             }
-
-            flexible_filter += StringMatcherFNMatch::convertMatchStringToFlexibleMatch( highlight_filter ) + "*";
-
-            matcher.setMatchString( flexible_filter );
-            matcher.setMatchCaseSensitive( false );
         }
     }
 
-    unsigned int i = 0;
-    std::string prefix_path = "";
-    bool smallest_match_found = false;
 
-    for ( std::vector< std::string >::const_iterator it1 = components.begin();
-          it1 != components.end();
+    if ( ! best_hit.empty() ) {
+        std::string f = best_hit;
+        f += "*";
+        
+        m_current_depth = find_best_matching_depth( m_current_entry, f );
+    } else {
+        if ( ! filter.empty() ) {
+            m_current_depth = find_best_matching_depth( m_current_entry, filter );
+        } else {
+            // workaround to adjust the depth to the name argument
+            m_current_depth = find_best_matching_depth( m_current_entry, name + "*" );
+        }
+    }
+
+    if ( m_entry_filter_mode != SHOW_ALL ) {
+        m_lv_dirty = true;
+    }
+
+    post_filtering();
+
+    return 0;
+}
+
+int PathJumpUI::set_entry( const std::string &name )
+{
+    bool found = false;
+
+    for ( std::list< pathjump_entry >::iterator it1 = m_entries.begin();
+          it1 != m_entries.end();
+          it1++ ) {
+        if ( ( it1->m_type == PATH_SHOW ||
+               it1->m_type == BOOKMARK_SHOW ) &&
+             it1->m_path == name ) {
+            m_current_entry = it1->m_path;
+            found = true;
+            break;
+        }
+    }
+
+    if ( found ) {
+        if ( ! m_filter.empty() &&
+             m_entry_filter_mode == SHOW_ALL ) {
+            m_current_depth = find_best_matching_depth( m_current_entry, m_filter );
+        }
+    } else {
+        find_entry( name, m_filter );
+    }
+
+    if ( m_entry_filter_mode != SHOW_ALL ) {
+        m_lv_dirty = true;
+    }
+
+    post_filtering();
+
+    return 0;
+}
+
+int PathJumpUI::post_filtering()
+{
+    std::string prefix_filter;
+
+    build_current_path_components( m_current_entry );
+
+    if ( m_entry_filter_mode != SHOW_ONLY_SUBDIRS &&
+         m_entry_filter_mode != SHOW_ONLY_DIRECT_SUBDIRS ) {
+
+        for ( std::list< pathjump_entry >::iterator it1 = m_entries.begin();
+              it1 != m_entries.end();
+              it1++ ) {
+            if ( it1->m_type == PATH_SHOW ||
+                 it1->m_type == BOOKMARK_SHOW ) {
+
+                if ( ! it1->m_post_filtering ) m_lv_dirty = true;
+
+                it1->m_post_filtering = true;
+            } else {
+
+                if ( it1->m_post_filtering ) m_lv_dirty = true;
+
+                it1->m_post_filtering = false;
+            }
+        }
+
+        return 0;
+    }
+
+    if ( m_current_depth > 0 ) {
+        int i = 0;
+        for ( std::vector< std::string >::const_iterator it1 = m_current_components.begin();
+              it1 != m_current_components.end();
+              it1++, i++ ) {
+            prefix_filter += "/";
+            prefix_filter += *it1;
+            if ( i + 1 >= m_current_depth ) break;
+        }
+    }
+
+    size_t l = prefix_filter.length();
+    std::map< std::string, bool > entry_visible;
+
+    for ( std::list< pathjump_entry >::iterator it1 = m_entries.begin();
+          it1 != m_entries.end();
+          it1++ ) {
+
+        bool new_state = false;
+
+        if ( it1->m_type == PATH_SHOW ||
+             it1->m_type == BOOKMARK_SHOW ) {
+            new_state = true;
+        }
+
+        if ( ! prefix_filter.empty() &&
+             ! AGUIXUtils::starts_with( it1->m_path,
+                                        prefix_filter ) ) {
+            new_state = false;
+        }
+
+        if ( m_entry_filter_mode == SHOW_ONLY_DIRECT_SUBDIRS &&
+             new_state ) {
+
+            size_t p2 = it1->m_path.find( '/', l + 1 );
+            std::string s;
+            if ( p2 != std::string::npos ) {
+                s = std::string( it1->m_path, 0, p2 );
+            } else {
+                s = it1->m_path;
+            }
+
+            if ( entry_visible[s] == true ) {
+                new_state = false;
+            } else {
+                entry_visible[s] = true;
+            }
+        }
+
+        if ( it1->m_post_filtering != new_state ) m_lv_dirty = true;
+
+        it1->m_post_filtering = new_state;
+    }
+
+    return 0;
+}
+
+int PathJumpUI::update_breadcrumb()
+{
+    unsigned int i = 0;
+    unsigned int last_component = m_current_components.size();
+
+    m_breadcrumb_buttons[i]->setText( 0, "/" );
+
+    if ( m_current_depth == (int)i ||
+         ( i == last_component && m_current_depth > (int)last_component ) ) {
+        m_breadcrumb_buttons[i]->setFG( 0, 2 );
+        m_breadcrumb_buttons[i]->setBG( 0, 3 );
+
+        m_breadcrumb_co->setMinWidth( m_breadcrumb_buttons[i]->getMaximumWidth(),
+                                      i, 0 );
+    } else {
+        m_breadcrumb_buttons[i]->setFG( 0, 1 );
+        m_breadcrumb_buttons[i]->setBG( 0, 0 );
+
+        m_breadcrumb_co->setMinWidth( 10,
+                                      i, 0 );
+    }
+
+    m_breadcrumb_buttons[i]->show();
+
+    m_breadcrumb_co->setMaxWidth( m_breadcrumb_buttons[i]->getMaximumWidth(),
+                                  i, 0 );
+    i++;
+
+    for ( std::vector< std::string >::const_iterator it1 = m_current_components.begin();
+          it1 != m_current_components.end();
           it1++ ) {
         if ( ! it1->empty() ) {
             m_breadcrumb_buttons[i]->setText( 0, it1->c_str() );
-            m_current_components.push_back( *it1 );
-            prefix_path += "/" + *it1;
 
-            if ( ! smallest_match_found &&
-                 ! highlight_filter.empty() &&
-                 matcher.match( prefix_path ) ) {
-                m_current_depth = i;
-                smallest_match_found = true;
-            }
-
-            if ( m_current_depth == (int)i ) {
+            if ( m_current_depth == (int)i ||
+                 ( i == last_component && m_current_depth > (int)last_component ) ) {
                 m_breadcrumb_buttons[i]->setFG( 0, 2 );
                 m_breadcrumb_buttons[i]->setBG( 0, 3 );
+
+                m_breadcrumb_co->setMinWidth( m_breadcrumb_buttons[i]->getMaximumWidth(),
+                                              i, 0 );
             } else {
                 m_breadcrumb_buttons[i]->setFG( 0, 1 );
                 m_breadcrumb_buttons[i]->setBG( 0, 0 );
+
+                m_breadcrumb_co->setMinWidth( 10,
+                                              i, 0 );
             }
 
             m_breadcrumb_buttons[i]->show();
@@ -697,6 +959,8 @@ int PathJumpUI::update_breadcrumb( const std::string &path,
         m_breadcrumb_buttons[i]->hide();
         m_breadcrumb_co->setMaxWidth( 0,
                                       i, 0 );
+        m_breadcrumb_co->setMinWidth( 0,
+                                      i, 0 );
     }
 
     m_win->updateCont();
@@ -704,26 +968,144 @@ int PathJumpUI::update_breadcrumb( const std::string &path,
     return 0;
 }
 
-int PathJumpUI::update_breadcrumb( const std::string &highlight_filter )
+int PathJumpUI::find_best_matching_depth( const std::string &filter )
 {
     if ( m_lv->isValidRow( m_lv->getActiveRow() ) == true ) {
-        if ( ! highlight_filter.empty() &&
-             highlight_filter[0] != '*' ) {
-            return update_breadcrumb( m_lv->getText( m_lv->getActiveRow(), 1 ),
-                                      "*" + highlight_filter );
-        } else {
-            return update_breadcrumb( m_lv->getText( m_lv->getActiveRow(), 1 ),
-                                      highlight_filter );
+        return find_best_matching_depth( m_lv->getText( m_lv->getActiveRow(), 1 ),
+                                         filter );
+    }
+    return -1;
+}
+
+int PathJumpUI::find_best_matching_depth( const std::string &path,
+                                          const std::string &filter )
+{
+    std::vector< std::string > components;
+    StringMatcherFNMatch matcher;
+    int depth = -1;
+
+    if ( filter.empty() ) return -1;
+
+    AGUIXUtils::split_string( components, path, '/' );
+
+    matcher.setMatchString( filter );
+    matcher.setMatchCaseSensitive( false );
+
+    if ( ! matcher.match( path ) ) {
+        std::string flexible_filter;
+
+        if ( filter[0] != '*' ) {
+            flexible_filter = "*";
         }
+
+        flexible_filter += StringMatcherFNMatch::convertMatchStringToFlexibleMatch( filter ) + "*";
+
+        matcher.setMatchString( flexible_filter );
+        matcher.setMatchCaseSensitive( false );
+    }
+
+    int i = 0;
+    std::string prefix_path = "";
+
+    for ( std::vector< std::string >::const_iterator it1 = components.begin();
+          it1 != components.end();
+          it1++ ) {
+        if ( ! it1->empty() ) {
+            prefix_path += "/" + *it1;
+
+            if ( matcher.match( prefix_path ) ) {
+                depth = i + 1;
+                break;
+            }
+
+            i++;
+        }
+    }
+
+    return depth;
+}
+
+int PathJumpUI::build_current_path_components()
+{
+    if ( m_lv->isValidRow( m_lv->getActiveRow() ) == true ) {
+        return build_current_path_components( m_lv->getText( m_lv->getActiveRow(), 1 ) );
     }
     return 1;
 }
 
-int PathJumpUI::update_breadcrumb()
+int PathJumpUI::build_current_path_components( const std::string &path )
 {
-    if ( m_lv->isValidRow( m_lv->getActiveRow() ) == true ) {
-        return update_breadcrumb( m_lv->getText( m_lv->getActiveRow(), 1 ),
-                                  "" );
+    std::vector< std::string > components;
+
+    m_current_components.clear();
+
+    AGUIXUtils::split_string( components, path, '/' );
+
+    if ( components.size() >= m_breadcrumb_buttons.size() ) {
+        // something wrong here, shouldn't happen
+        return 1;
     }
-    return 1;
+
+    for ( std::vector< std::string >::const_iterator it1 = components.begin();
+          it1 != components.end();
+          it1++ ) {
+        if ( ! it1->empty() ) {
+            m_current_components.push_back( *it1 );
+        }
+    }
+
+    return 0;
+}
+
+int PathJumpUI::cleanup()
+{
+    std::string msg, bt;
+
+    std::list< std::string > temp_paths = m_worker.getPathsPers(),
+        non_existing_entries;
+
+    int non_existing = 0, sum = 0;
+
+    m_win->setCursor( AGUIX::WAIT_CURSOR );
+    m_aguix.Flush();
+
+    for ( std::list< std::string >::const_iterator it1 = temp_paths.begin();
+          it1 != temp_paths.end();
+          it1++ ) {
+        if ( ! NWC::FSEntry( *it1 ).entryExists() ) {
+            non_existing_entries.push_back( *it1 );
+            non_existing++;
+        }
+
+        sum++;
+    }
+
+    m_win->unsetCursor();
+
+    if ( non_existing > 0 ) {
+        msg = AGUIXUtils::formatStringToString( catalog.getLocale( 985 ),
+                                                non_existing, sum );
+
+        bt = catalog.getLocale( 11 );
+        bt += "|";
+        bt += catalog.getLocale( 8 );
+
+        int res = m_win->request( catalog.getLocale( 123 ),
+                                  msg.c_str(),
+                                  bt.c_str() );
+
+        if ( res == 0 ) {
+            for ( std::list< std::string >::const_iterator it1 = non_existing_entries.begin();
+                  it1 != non_existing_entries.end();
+                  it1++ ) {
+                m_worker.removePathPers( *it1 );
+            }
+        }
+    } else {
+        m_win->request( catalog.getLocale( 123 ),
+                        catalog.getLocale( 986 ),
+                        catalog.getLocale( 633 ) );
+    }
+
+    return 0;
 }
