@@ -1,6 +1,6 @@
 /* run_custom_action.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2007-2008 Ralf Hoffmann.
+ * Copyright (C) 2007-2008,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -29,6 +29,13 @@
 #include <string>
 #include <vector>
 #include <algorithm>
+#include "worker_locale.h"
+#include "dnd.h"
+#include "wconfig.h"
+#include <aguix/stringgadget.h>
+#include <aguix/fieldlistview.h>
+#include <aguix/button.h>
+#include "datei.h"
 
 const char *RunCustomAction::name = "RunCustomAction";
 
@@ -46,6 +53,7 @@ const char *RunCustomAction::getName()
 RunCustomAction::RunCustomAction() : FunctionProto(), m_customname( "" )
 {
     hasConfigure = true;
+    m_category = FunctionProto::CAT_FILETYPE;
 }
 
 RunCustomAction::~RunCustomAction()
