@@ -93,6 +93,7 @@ ScriptOp::duplicate() const
   ta->setProgressUseOutput( progress_useoutput );
   ta->setWinText( wintext );
   ta->setWinTextUseOutput( wintext_useoutput );
+  ta->setCommandStr( m_command_str );
   return ta;
 }
 
@@ -376,6 +377,22 @@ ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
         }
       }
       break;
+    case SCRIPT_EVALCOMMAND:
+        if ( ! m_command_str.empty() ) {
+            std::string res_str;
+
+            if ( wpu->parse( m_command_str.c_str(), res_str, a_max( EXE_STRING_LEN - 1024, 256 ),
+                             true ) == NormalMode::PARSE_SUCCESS ) {
+                Lister *l1 = msg->getWorker()->getActiveLister();
+                if ( l1 != NULL ) {
+                    ListerMode *lm1 = l1->getActiveMode();
+                    if ( lm1 != NULL ) {
+                        lm1->runCommandWithStrArgs( res_str );
+                    }
+                }
+            }
+        }
+        break;
     default:
       break;
   }
@@ -441,6 +458,10 @@ ScriptOp::getDescription()
       str1 += "goto ";
       str1 += ( label != NULL ) ? label : "";
       break;
+    case SCRIPT_EVALCOMMAND:
+      str1 += "evaluate ";
+      str1 += m_command_str;
+      break;
     default:
       str1 += "nop";
       break;
@@ -564,9 +585,9 @@ int ScriptOp::configure()
   int endmode=-1;
   char *tstr;
   char buf[ A_BYTESFORNUMBER( int ) ];
-  AWindow *push_win, *label_win, *if_win, *nop_win, *pop_win, *end_win, *set_win, *win_win, *goto_win;
+  AWindow *push_win, *label_win, *if_win, *nop_win, *pop_win, *end_win, *set_win, *win_win, *goto_win, *command_win;
   StringGadget *popsg;
-  AWindow *winlist[9];
+  AWindow *winlist[10];
   int cur_win;
   int trow, i, tw, th;
   const int cincw = AContainer::ACONT_MINH +
@@ -628,6 +649,9 @@ int ScriptOp::configure()
   trow = lv->addRow();
   lv->setText( trow, 0, catalog.getLocale ( 515 ) );
   lv->setPreColors( trow, FieldListView::PRECOLOR_ONLYACTIVE );
+  trow = lv->addRow();
+  lv->setText( trow, 0, catalog.getLocale ( 988 ) );
+  lv->setPreColors( trow, FieldListView::PRECOLOR_ONLYACTIVE );
   lv->maximizeX();
   lv->maximizeY();
   if ( type == SCRIPT_PUSH ) lv->setActiveRow( 1 );
@@ -638,6 +662,7 @@ int ScriptOp::configure()
   else if ( type == SCRIPT_SETTINGS ) lv->setActiveRow( 6 );
   else if ( type == SCRIPT_WINDOW ) lv->setActiveRow( 7 );
   else if ( type == SCRIPT_GOTO ) lv->setActiveRow( 8 );
+  else if ( type == SCRIPT_EVALCOMMAND ) lv->setActiveRow( 9 );
   else lv->setActiveRow( 0 );
   ac1->readLimits();
 
@@ -979,6 +1004,36 @@ int ScriptOp::configure()
 									     ( label != NULL ) ? label : "",
 									     0 ), 1, 0, cincw );
   
+  command_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  ac1->add( command_win, 0, 2, cmin );
+  command_win->create();
+  command_win->setBorderWidth( 0 );
+
+  AContainer *command_win_ac1 = command_win->setContainer( new AContainer( command_win, 1, 2 ), true );
+  command_win_ac1->setMinSpace( 5 );
+  command_win_ac1->setMaxSpace( 5 );
+  command_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 989 ), 1 ), 0, 0, cincwnr );
+
+  AContainer *command_win_ac1_2 = command_win_ac1->add( new AContainer( command_win, 3, 1 ), 0, 1 );
+  command_win_ac1_2->setMinSpace( 5 );
+  command_win_ac1_2->setMaxSpace( 5 );
+  command_win_ac1_2->setBorderWidth( 0 );
+
+  command_win_ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 990 ), 1 ), 0, 0, cfix );
+  StringGadget *cmdsg = (StringGadget*)command_win_ac1_2->add( new StringGadget( aguix,
+                                                                                 0,
+                                                                                 0,
+                                                                                 100,
+                                                                                 m_command_str.c_str(),
+                                                                                 0 ), 1, 0, cincw );
+  Button *cmd_flag_b = (Button*)command_win_ac1_2->add( new Button( aguix,
+                                                                 0,
+                                                                 0,
+                                                                 "F",
+                                                                 1,
+                                                                 0,
+                                                                 0 ), 2, 0, cfix );
+
   AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 3 );
   ac1_2->setMinSpace( 5 );
   ac1_2->setMaxSpace( -1 );
@@ -1009,11 +1064,12 @@ int ScriptOp::configure()
   winlist[6] = set_win;
   winlist[7] = win_win;
   winlist[8] = goto_win;
+  winlist[9] = command_win;
 
   tw = 0;
   th = 0;
   AWindow *twin;
-  for ( i = 0; i < 9; i++ ) {
+  for ( i = 0; i < 10; i++ ) {
     twin = winlist[i];
     twin->contMaximize();
     if ( twin->getWidth() > tw ) tw = twin->getWidth();
@@ -1049,11 +1105,14 @@ int ScriptOp::configure()
     case SCRIPT_GOTO:
       cur_win = 8;
       break;
+    case SCRIPT_EVALCOMMAND:
+      cur_win = 9;
+      break;
     default:
       cur_win = 0;
       break;
   }
-  for ( i = 0; i < 9; i++ ) {
+  for ( i = 0; i < 10; i++ ) {
     if ( i != cur_win )
       winlist[i]->hide();
     else {
@@ -1106,14 +1165,20 @@ int ScriptOp::configure()
             Requester *req = new Requester( aguix );
             req->request( catalog.getLocale( 124 ), catalog.getLocale( 489 ), catalog.getLocale( 11 ) );
             delete req;
+          } else if ( msg->button.button == cmd_flag_b ) {
+            tstr = getPushFlag();
+            if ( tstr != NULL ) {
+              cmdsg->insertAtCursor( tstr );
+              _freesafe( tstr );
+            }
           }
           break;
         case AG_FIELDLV_ONESELECT:
         case AG_FIELDLV_MULTISELECT:
           if ( msg->fieldlv.lv == lv ) {
             cur_win = lv->getActiveRow();
-            if ( ( cur_win < 0 ) || ( cur_win > 8 ) ) cur_win = 0;
-	    for ( i = 0; i < 9; i++ ) {
+            if ( ( cur_win < 0 ) || ( cur_win > 9 ) ) cur_win = 0;
+	    for ( i = 0; i < 10; i++ ) {
 	      if ( i != cur_win )
 		winlist[i]->hide();
 	      else {
@@ -1197,6 +1262,10 @@ int ScriptOp::configure()
         type = SCRIPT_GOTO;
         setLabel( gotosg->getText() );
         break;
+      case 9:
+        type = SCRIPT_EVALCOMMAND;
+        setCommandStr( cmdsg->getText() );
+        break;
       default:
         type = SCRIPT_NOP;
         break;
@@ -1235,6 +1304,9 @@ bool ScriptOp::save(Datei *fh)
     case SCRIPT_GOTO:
       fh->configPutPair( "type", "goto" );
       break;
+    case SCRIPT_EVALCOMMAND:
+      fh->configPutPair( "type", "evalcommand" );
+      break;
     default:
       fh->configPutPair( "type", "nop" );
       break;
@@ -1279,6 +1351,10 @@ bool ScriptOp::save(Datei *fh)
     fh->configPutPairString( "wintext", wintext );
   }
 
+  if ( ! m_command_str.empty() ) {
+      fh->configPutPairString( "commandstring", m_command_str.c_str() );
+  }
+
   return true;
 }
 
@@ -1512,3 +1588,12 @@ bool ScriptOp::getWinTextUseOutput()
   return wintext_useoutput;
 }
 
+void ScriptOp::setCommandStr( const std::string &str )
+{
+    m_command_str = str;
+}
+
+std::string ScriptOp::getCommandStr() const
+{
+    return m_command_str;
+}
