@@ -1,6 +1,6 @@
 /* searchentryop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2009,2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2004,2009,2011-2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -32,10 +32,10 @@ const char *SearchEntryOp::name="SearchEntryOp";
 
 SearchEntryOp::SearchEntryOp() : FunctionProto()
 {
-  ignore_case = false;
-  reverse_search = false;
-  m_infix_search = false;
-  hasConfigure = true;
+    ignore_case = true;
+    reverse_search = false;
+    m_infix_search = false;
+    hasConfigure = true;
     m_category = FunctionProto::CAT_CURSOR;
     m_flexible_match = true;
 }
