@@ -1,6 +1,6 @@
 /* searchopbg.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006-2008,2010-2011 Ralf Hoffmann.
+ * Copyright (C) 2006-2008,2010-2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -1067,8 +1067,13 @@ void SearchOpBG::createWindow()
     w = m_win->getWidth();
     h = m_win->getHeight();
 
-    sw = aguix->getRootWindowWidth();
-    sh = aguix->getRootWindowHeight();
+    int rx, ry, rw, rh;
+
+    aguix->getLargestDimensionOfCurrentScreen( &rx, &ry,
+                                               &rw, &rh );
+
+    sw = rw;
+    sh = rh;
     sw = (int)( (double)sw * 0.6 );
     sh = (int)( (double)sh * 0.7 );
     if ( sw < 200 ) sw = 200;
