@@ -1,6 +1,6 @@
 /* setfilterop.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2008 Ralf Hoffmann.
+ * Copyright (C) 2001-2004,2008,2010-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -24,15 +24,15 @@
 
 #include "wdefines.h"
 #include "functionproto.h"
-#include <aguix/util.h>
 #include <string>
 #include "dirfiltersettings.hh"
-#include <aguix/message.h>
 #include <map>
+#include <aguix/message.h>
 
 class Worker;
 class PopUpMenu;
 class SetFilterCB;
+class PersistentStringList;
 
 class SetFilterOp:public FunctionProto
 {
@@ -45,9 +45,7 @@ public:
   virtual SetFilterOp *duplicate() const;
   virtual bool isName(const char *);
   virtual const char *getName();
-#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
   using FunctionProto::run;
-#endif
   int run( WPUContext *wpu, ActionMessage* );
   virtual bool save(Datei*);
   virtual const char *getDescription();
@@ -78,7 +76,7 @@ protected:
   static const char *name;
   // Infos to save
   bool request_flags;
-  char *filter;
+  std::string filter;
   setfilterop_mode filtermode;
   std::string m_bookmark_label;
   DirFilterSettings::bookmark_filter_t m_bookmark_filter;
@@ -90,7 +88,7 @@ protected:
   Lister *startlister,*endlister;
   
   // temp values filled when request_flags==true
-  char *tfilter;
+  std::string tfilter;
   setfilterop_mode tfiltermode;
   std::string m_t_bookmark_label;
   DirFilterSettings::bookmark_filter_t m_t_bookmark_filter;
@@ -100,11 +98,11 @@ protected:
 
   int normalmodesf( ActionMessage* );
 
-  void addHistoryItem( const char *str );
-  static List *filter_history;
+  void addHistoryItem( const std::string &str );
+  static std::auto_ptr< PersistentStringList > m_history;
 private:
   static int instance_counter;
-  static int history_size;
+  static size_t history_size;
   void initHistory();
   void closeHistory();
 
@@ -131,3 +129,7 @@ private:
 };
 
 #endif
+
+/* Local Variables: */
+/* mode:c++ */
+/* End: */
