@@ -1,6 +1,6 @@
 /* setsortmodeop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2008,2010 Ralf Hoffmann.
+ * Copyright (C) 2001-2004,2008,2010-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -24,6 +24,11 @@
 #include "normalmode.h"
 #include "worker.h"
 #include "verzeichnis.hh"
+#include "datei.h"
+#include <aguix/button.h>
+#include <aguix/cyclebutton.h>
+#include <aguix/choosebutton.h>
+#include "worker_locale.h"
 
 /*****************
  SetSortmodeOp
@@ -35,6 +40,7 @@ SetSortmodeOp::SetSortmodeOp() : FunctionProto()
 {
   mode=SORT_NAME;
   hasConfigure = true;
+    m_category = FunctionProto::CAT_FILELIST;
 }
 
 SetSortmodeOp::~SetSortmodeOp()
