@@ -1,6 +1,6 @@
 /* dirsizeop.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2004,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,12 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
-/* $Id: showdircacheop.cc,v 1.5 2005/10/19 18:00:18 ralf Exp $ */
 
 #include "showdircacheop.h"
 #include "listermode.h"
 #include "normalmode.h"
 #include "worker.h"
+#include "worker_locale.h"
 
 const char *ShowDirCacheOp::name = "ShowDirCacheOp";
 
