@@ -392,7 +392,7 @@ void ShowImageMode::update(bool force)
           _freesafe( buf );
           buf = buf2;
           blank();
-          system(buf);
+          (void)system( buf );
           blanked=false;
           
           _freesafe(buf);
