@@ -1,6 +1,6 @@
 /* startprogop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2008,2010-2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2008,2010-2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -735,7 +735,12 @@ std::auto_ptr< StartProgOp::StartSettings > StartProgOp::showGUI()
   w = win->getWidth();
   h = win->getHeight();
 
-  sw = aguix->getRootWindowWidth();
+  int rx, ry, rw, rh;
+
+  aguix->getLargestDimensionOfCurrentScreen( &rx, &ry,
+                                             &rw, &rh );
+
+  sw = rw;
   sw = (int)( (double)sw * 0.8 );
   if ( sw < 200 ) sw = 200;
   if ( w < sw ) w = sw;
