@@ -1,6 +1,6 @@
 /* textstoragefile.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2005-2007 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2005-2007,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -27,6 +27,7 @@
 #include "worker_locale.h"
 #include "pdatei.h"
 #include <errno.h>
+#include <aguix/lowlevelfunc.h>
 
 TextStorageFile::TextStorageFile( const std::string &filename,
                                   const RefCount<AWidth> &lencalc,
@@ -231,3 +232,21 @@ std::pair< std::pair< int, int >, int > TextStorageFile::getLineForOffset( int u
     return m_tss.getLineForOffset( unwrapped_line_nr,
                                    line_offset );
 }
+
+void TextStorageFile::setFileName( const std::string &filename, int initial_size )
+{
+    if ( initial_size > 0 && initial_size <= 1 * 1024 * 1024 * 1024 ) {
+        m_current_size = initial_size;
+    }
+
+    m_incomplete_file = true;
+    m_file_size = -1;
+    m_filename = filename;
+    
+    readFile();
+}
+
+int TextStorageFile::getCurrentSize() const
+{
+    return m_current_size;
+}
