@@ -1,6 +1,6 @@
 /* verzeichnis.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2007,2010 Ralf Hoffmann.
+ * Copyright (C) 2001-2007,2010-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -29,6 +29,10 @@
 #include <algorithm>
 #include <functional>
 #include <nwc_path.hh>
+#include "worker_locale.h"
+#include "fileentry.hh"
+#include <aguix/request.h>
+#include "stringcomparator.hh"
 
 Verzeichnis::Verzeichnis() : _dir_opened( false ),
                              _highest_ID_plus_one( 0 ),
@@ -153,7 +157,7 @@ int Verzeichnis::sortfunction(void *p1,void *p2,int mode)
 
     switch(mode&0xff) {
       case SORT_NAME:
-          comp=strcmp(fe1->name,fe2->name);
+          comp = StringComparator::compare( fe1->name, fe2->name );
           break;
       case SORT_SIZE:
           s1=-1;
