@@ -346,8 +346,13 @@ void VolumeManagerUI::maximizeWin()
         if ( my_w < 400 ) my_w = 400;
         if ( my_h < 300 ) my_h = 300;
 
-        int mw = m_aguix.getRootWindowWidth() * 80 / 100;
-        int mh = m_aguix.getRootWindowHeight() * 80 / 100;
+        int rx, ry, rw, rh;
+
+        m_aguix.getLargestDimensionOfCurrentScreen( &rx, &ry,
+                                                    &rw, &rh );
+
+        int mw = rw * 80 / 100;
+        int mh = rh * 80 / 100;
         m_cont2->resize( mw, mh );
         m_cont2->rearrange();
 
