@@ -1,6 +1,6 @@
 /* waitthread.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2009-2010 Ralf Hoffmann.
+ * Copyright (C) 2009-2010,2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -31,7 +31,8 @@ WaitThread::WaitThread( RefCount< EventQueue > eq,
                         RefCount< TimeoutStore > timeouts ) : m_eq( eq ),
                                                               m_timeouts( timeouts ),
                                                               m_fd( -1 ),
-                                                              m_fd2( - 1 ),
+                                                              m_fd2( -1 ),
+                                                              m_fd3( -1 ),
                                                               m_state( WAITTHREAD_NONE )
 {
 }
@@ -80,6 +81,13 @@ int WaitThread::run()
             }
         }
 
+        if ( m_fd3 >= 0 ) {
+            FD_SET( m_fd3, &rdfs );
+            if ( ( m_fd3 + 1 ) > max_fd_plus_one ) {
+                max_fd_plus_one = m_fd3 + 1;
+            }
+        }
+
         if ( timeout_ms < 1 ) {
             ret = select( max_fd_plus_one, &rdfs, NULL, NULL, NULL );
         } else {
@@ -92,6 +100,8 @@ int WaitThread::run()
         if ( ret > 0 ) {
             if ( m_fd2 >= 0 && FD_ISSET( m_fd2, &rdfs ) ) {
                 m_eq->push( EventQueue::EQ_FD2 );
+            } else if ( m_fd3 >= 0 && FD_ISSET( m_fd3, &rdfs ) ) {
+                m_eq->push( EventQueue::EQ_FD3 );
             } else {
                 m_eq->push( EventQueue::EQ_XEVENT );
             }
@@ -128,3 +138,9 @@ void WaitThread::watchFD2( int fd2 )
     m_fd2 = fd2;
     if ( m_fd2 < -1 ) m_fd2 = -1;
 }
+
+void WaitThread::watchFD3( int fd3 )
+{
+    m_fd3 = fd3;
+    if ( m_fd3 < -1 ) m_fd3 = -1;
+}
