@@ -127,6 +127,8 @@ public:
   int getClockbarUpdatetime();
   void setClockbarCommand(const char *);
   const char *getClockbarCommand();
+  void setClockbarHints( bool );
+  bool getClockbarHints();
   void setDontCheckDirs(List*);
   List *getDontCheckDirs();
   void setDontCheckVirtual( bool );
@@ -370,6 +372,7 @@ protected:
   clockbar_mode_t clockbar_mode;
   int clockbar_updatetime;
   char *clockbar_command;
+  bool m_clockbar_hints;
   List *dontcheckdirs;
   bool dontcheckvirtual;
   
