@@ -56,13 +56,10 @@ ButtonPanel::~ButtonPanel()
 
 int ButtonPanel::create()
 {
-  int res;
-  
-  res = Panel::create();
+  Panel::create();
 
   int i;
   unsigned int i2;
-  Text *mtext;
   
   AContainer *ac1 = setContainer( new AContainer( this, 1, 6 ), true );
   ac1->setMinSpace( 5 );
@@ -149,7 +146,7 @@ int ButtonPanel::create()
   ac1_3->setMinSpace( 5 );
   ac1_3->setMaxSpace( 5 );
   ac1_3->setBorderWidth( 0 );
-  mtext = (Text*)ac1_3->add( new Text( _aguix, 0, 0, catalog.getLocale( 227 ), 1 ), 0, 0, AContainer::CO_FIX );
+  ac1_3->add( new Text( _aguix, 0, 0, catalog.getLocale( 227 ), 1 ), 0, 0, AContainer::CO_FIX );
   cyb = new CycleButton( _aguix, 0, 0, 100, 1, 0, 0 );
   cyb->addOption( catalog.getLocale( 228 ) );
   cyb->addOption( catalog.getLocale( 229 ) );
