@@ -37,9 +37,7 @@ ButtonGrpConfPanel::~ButtonGrpConfPanel()
 
 int ButtonGrpConfPanel::create()
 {
-  int res;
-  
-  res = Panel::create();
+  Panel::create();
 
   char buf[ A_BYTESFORNUMBER( int ) ];
 
