@@ -34,9 +34,7 @@ CacheSizePanel::~CacheSizePanel()
 
 int CacheSizePanel::create()
 {
-  int res;
-  
-  res = Panel::create();
+  Panel::create();
 
   char buf[ A_BYTESFORNUMBER( int ) ];
 
