@@ -72,12 +72,11 @@ ColorPanel::~ColorPanel()
 
 int ColorPanel::create()
 {
-  int res;
   int i;
   int trow;
   int fg,bg;
   
-  res = Panel::create();
+  Panel::create();
 
   AContainer *ac1 = setContainer( new AContainer( this, 1, 13 ), true );
   ac1->setMinSpace( 5 );
