@@ -40,9 +40,7 @@ ColorConfPanel::~ColorConfPanel()
 
 int ColorConfPanel::create()
 {
-  int res;
-  
-  res = Panel::create();
+  Panel::create();
 
   char buf[ A_BYTESFORNUMBER( int ) ];
 
