@@ -1,6 +1,6 @@
 /* wconfig_dcd.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006,2011 Ralf Hoffmann.
+ * Copyright (C) 2006,2011-2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -28,6 +28,7 @@
 #include <aguix/choosebutton.h>
 #include "simplelist.hh"
 #include "datei.h"
+#include "nwc_path.hh"
 
 DCDPanel::DCDPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
 {
@@ -140,7 +141,7 @@ void DCDPanel::run( Widget *elem, AGMessage &msg )
       if ( string_request( catalog.getLocale( 123 ), textstr, "", buttonstr, &tstr ) == 0 ) {
 	if(strlen(tstr)>0) {
 	  if(tstr[0]=='/') {
-	    tstr2=HandlePath(tstr);
+	    tstr2=NWC::Path::handlePath(tstr);
 	    
 	    found=false;
 	    trow = 0;
@@ -186,7 +187,7 @@ void DCDPanel::run( Widget *elem, AGMessage &msg )
                              &tstr ) == 0 ) {
 	  if(strlen(tstr)>0) {
 	    if(tstr[0]=='/') {
-	      tstr2=HandlePath(tstr);
+	      tstr2=NWC::Path::handlePath(tstr);
 	      
 	      found=false;
 	      trow2 = 0;
