@@ -35,9 +35,7 @@ DirSizeConfPanel::~DirSizeConfPanel()
 
 int DirSizeConfPanel::create()
 {
-  int res;
-  
-  res = Panel::create();
+  Panel::create();
 
   AContainer *ac1 = setContainer( new AContainer( this, 1, 2 ), true );
   ac1->setMinSpace( 5 );
