@@ -47,9 +47,7 @@ FiletypePanel::~FiletypePanel()
 
 int FiletypePanel::create()
 {
-  int res;
-  
-  res = Panel::create();
+  Panel::create();
 
   AContainer *ac1 = setContainer( new AContainer( this, 1, 4 ), true );
   ac1->setMinSpace( 5 );
