@@ -38,9 +38,7 @@ FontPanel::~FontPanel()
 
 int FontPanel::create()
 {
-  int res;
-  
-  res = Panel::create();
+  Panel::create();
 
   ac1 = setContainer( new AContainer( this, 1, 11 ), true );
   ac1->setBorderWidth( 5 );
