@@ -36,9 +36,7 @@ GeneralConfPanel::~GeneralConfPanel()
 
 int GeneralConfPanel::create()
 {
-    int res;
-    
-    res = Panel::create();
+    Panel::create();
     
     AContainer *ac1 = setContainer( new AContainer( this, 1, 2 ), true );
     ac1->setMinSpace( 5 );
