@@ -38,9 +38,7 @@ HotkeyPanel::~HotkeyPanel()
 
 int HotkeyPanel::create()
 {
-  int res;
-  
-  res = Panel::create();
+  Panel::create();
 
   int row;
 
