@@ -39,9 +39,7 @@ ImExportPanel::~ImExportPanel()
 
 int ImExportPanel::create()
 {
-  int res;
-  
-  res = Panel::create();
+  Panel::create();
   
   AContainer *ac1 = setContainer( new AContainer( this, 1, 3 ), true );
   ac1->setBorderWidth( 5 );
