@@ -137,9 +137,7 @@ LayoutPanel::~LayoutPanel()
 
 int LayoutPanel::create()
 {
-  int res;
-  
-  res = Panel::create();
+  Panel::create();
 
   int n, i;
   Text **texts;
