@@ -37,9 +37,7 @@ ListViewPanel::~ListViewPanel()
 
 int ListViewPanel::create()
 {
-  int res;
-  
-  res = Panel::create();
+  Panel::create();
 
   unsigned int j, ui;
   int trow;
