@@ -36,9 +36,7 @@ MousePanel::~MousePanel()
 
 int MousePanel::create()
 {
-  int res;
-  
-  res = Panel::create();
+  Panel::create();
 
   AContainer *ac1 = setContainer( new AContainer( this, 1, 3 ), true );
   ac1->setMinSpace( 5 );
