@@ -34,9 +34,7 @@ OwnerConfPanel::~OwnerConfPanel()
 
 int OwnerConfPanel::create()
 {
-  int res;
-  
-  res = Panel::create();
+  Panel::create();
 
   AContainer *ac1 = setContainer( new AContainer( this, 1, 2 ), true );
   ac1->setMinSpace( 5 );
