@@ -50,9 +50,7 @@ PalettePanel::~PalettePanel()
 int PalettePanel::create()
 {
   int sx;
-  int res;
-
-  res = Panel::create();
+  Panel::create();
   
   AContainer *ac1 = setContainer( new AContainer( this, 1, 2 ), true );
   ac1->setMinSpace( 5 );
@@ -98,11 +96,11 @@ int PalettePanel::create()
   ac1_2_1->setMaxSpace( 5 );
   ac1_2_1->setBorderWidth( 0 );
 
-  Text *label1 = (Text*)ac1_2_1->add( new Text( _aguix,
-						0,
-						0,
-						catalog.getLocale(27),
-						1 ), 0, 0, AContainer::CO_FIX );
+  ac1_2_1->add( new Text( _aguix,
+                          0,
+                          0,
+                          catalog.getLocale(27),
+                          1 ), 0, 0, AContainer::CO_FIX );
   palentryt = (Text*)ac1_2_1->add( new Text( _aguix,
                                              0,
                                              0,
@@ -114,11 +112,11 @@ int PalettePanel::create()
   ac1_2_2->setMaxSpace( 5 );
   ac1_2_2->setBorderWidth( 0 );
 
-  label1=(Text*)ac1_2_2->add( new Text( _aguix,
-					0,
-					0,
-					catalog.getLocale(28),
-					1), 0, 0, AContainer::CO_FIX );
+  ac1_2_2->add( new Text( _aguix,
+                          0,
+                          0,
+                          catalog.getLocale(28),
+                          1), 0, 0, AContainer::CO_FIX );
   redsg = (StringGadget*)ac1_2_2->add( new StringGadget( _aguix,
                                                          0,
                                                          0,
@@ -137,11 +135,11 @@ int PalettePanel::create()
   redsl->setMaxDisplay( 1 );
   redsl->setMaxLen( 256 );
   redsl->setDisplayFocus( true );
-  label1 = (Text*)ac1_2_2->add( new Text( _aguix,
-					  0,
-					  0,
-					  catalog.getLocale( 29 ),
-					  1 ), 0, 1, AContainer::CO_FIX );
+  ac1_2_2->add( new Text( _aguix,
+                          0,
+                          0,
+                          catalog.getLocale( 29 ),
+                          1 ), 0, 1, AContainer::CO_FIX );
   greensg = (StringGadget*)ac1_2_2->add( new StringGadget( _aguix,
                                                            0,
                                                            0,
@@ -160,11 +158,11 @@ int PalettePanel::create()
   greensl->setMaxDisplay( 1 );
   greensl->setMaxLen( 256 );
   greensl->setDisplayFocus( true );
-  label1 = (Text*)ac1_2_2->add( new Text( _aguix,
-					  0,
-					  0,
-					  catalog.getLocale( 30 ),
-					  1 ), 0, 2, AContainer::CO_FIX );
+  ac1_2_2->add( new Text( _aguix,
+                          0,
+                          0,
+                          catalog.getLocale( 30 ),
+                          1 ), 0, 2, AContainer::CO_FIX );
   bluesg = (StringGadget*)ac1_2_2->add( new StringGadget( _aguix,
                                                           0,
                                                           0,
