@@ -35,9 +35,7 @@ StartPanel::~StartPanel()
 
 int StartPanel::create()
 {
-  int res;
-  
-  res = Panel::create();
+  Panel::create();
 
   AContainer *ac1 = setContainer( new AContainer( this, 1, 2 ), true );
   ac1->setBorderWidth( 5 );
