@@ -38,9 +38,7 @@ TimePanel::~TimePanel()
 
 int TimePanel::create()
 {
-  int res;
-  
-  res = Panel::create();
+  Panel::create();
 
   int i;
   char buf[128];
