@@ -36,6 +36,7 @@
 #include "event_callbacks.hh"
 #include "temporaryfilecache.hh"
 #include "deeppathstore.hh"
+#include <set>
 
 class ListerMode;
 class Lister;
@@ -55,6 +56,9 @@ class WCPath;
 class PartSpace;
 class CopyfileProgressCallback;
 class PersDeepPathStore;
+class HintDB;
+class PathnameWatcher;
+class Slider;
 
 class Worker
 {
@@ -75,7 +79,7 @@ public:
   AWindow *getMainWin();
   void setStatebarText(const char*);
   static int getNrOfCommands();
-  FunctionProto *getCommand4ID(int);
+  static FunctionProto *getCommand4ID(int);
   static int getID4Command(FunctionProto*);
   Lister *getOtherLister(Lister*);
   int getSide(Lister*);
@@ -153,9 +157,14 @@ public:
     DeepPathStore &getPathStore();
 
     void storePathPers( const std::string &path );
+    void removePathPers( const std::string &path );
     std::list< std::string > getPathsPers();
 
     void copyToClipboard( const std::string &str );
+
+    void showNextHint();
+
+    RefCount< PathnameWatcher > getPathnameWatcher();
  protected:
   void createMainWin();
   void setupMainWin();
@@ -182,6 +191,7 @@ public:
   Button *statebar;
   Button **pathbs;
   Button **buttons;
+  Slider *button_bank_slider;
   AWindow *listerwin[2];
   AContainer *maincont;
   
@@ -313,8 +323,16 @@ public:
     std::map< EventCallbacks::event_callback_type_t, bool > m_events_seen;
     void fireSeenEvents();
 
+    void updateHintDB();
+
     DeepPathStore m_path_store;
     std::auto_ptr< PersDeepPathStore > m_pers_path_store;
+
+    std::string m_current_hint;
+    time_t m_hint_time;
+    RefCount< HintDB > m_hint_db;
+    RefCount< PathnameWatcher > m_pathname_watcher;
+    std::set< std::string > m_changed_paths;
 };
 
 #endif
