@@ -1,6 +1,6 @@
 /* worker_commands.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2007,2009,2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2007,2009,2011-2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -205,6 +205,12 @@ FunctionProto *Worker::getCommand4ID(int id)
     case 59:
       fpr = new SwitchButtonBankOp();
       break;
+    case 60:
+      fpr = new PathJumpOp();
+      break;
+    case 61:
+      fpr = new ClipboardOp();
+      break;
     default:
       fpr=new DNDAction();
   }
@@ -274,6 +280,8 @@ int Worker::getID4Command(FunctionProto *fpr)
   else if ( fpr->isName( ChangeLayoutOp::name ) == true ) type = 57;
   else if ( fpr->isName( VolumeManagerOp::name ) == true ) type = 58;
   else if ( fpr->isName( SwitchButtonBankOp::name ) == true ) type = 59;
+  else if ( fpr->isName( PathJumpOp::name ) == true ) type = 60;
+  else if ( fpr->isName( ClipboardOp::name ) == true ) type = 61;
   return type;
 }
 
