@@ -27,7 +27,7 @@
 #include "nwc_path.hh"
 #include "datei.h"
 
-#define CATENTRY 980
+#define CATENTRY 994
 #define CATCOMENTRY 62
 #define CATFLAGENTRY 59
 
@@ -1079,9 +1079,23 @@ match any font." );
   catalog[974]=dupstring( "Path jump" );
   catalog[975]=dupstring( "List of allowed directories to track for path jump command.|All those directories and their sub-directories are allowed to store in a local database|to allow faster access to often used directories. It's a prefix comparison|so add a trailing slash if necessary to avoid mismatches." );
   catalog[976]=dupstring( "Enter directory to allow to be tracked by the path jump command:" );
-  catalog[977]=dupstring( "Also show entries from bookmarks and persistant path store (Ctrl+a)" );
+  catalog[977]=dupstring( "Also show entries from bookmarks and persistent path store (Ctrl+a)" );
   catalog[978]=dupstring( "Match quality" );
   catalog[979]=dupstring( "String copied to clipboard:" );
+  catalog[980]=dupstring( "Display mode (Ctrl+f):" );
+  catalog[981]=dupstring( "All entries" );
+  catalog[982]=dupstring( "Only subdirectories" );
+  catalog[983]=dupstring( "Only direct subdirectories" );
+  catalog[984]=dupstring( "Cleanup persistent list" );
+  catalog[985]=dupstring( "%d of %d entries in the persistent list of visited paths|do no longer exists, remove them from the list?" );
+  catalog[986]=dupstring( "All entries still exist, nothing to remove." );
+  catalog[987]=dupstring( "Show hints" );
+  catalog[988]=dupstring( "evaluate command" );
+  catalog[989]=dupstring( "Evalute an internally registered command" );
+  catalog[990]=dupstring( "Command:" );
+  catalog[991]=dupstring( "Watch directories for changes" );
+  catalog[992]=dupstring( "There is not enough space on target %s.|Free space is %s. Still continuing?" );
+  catalog[993]=dupstring( "Command %s not found" );
 
 //  catalog[]=dupstring( "" );
   
