@@ -200,6 +200,15 @@ WPUContext::WPUContext( Worker *w, List *coms, bool delete_commands_at_destroy,
             extlist[0]->setTakeDirs( extorder.take_dirs );
           }
         }
+      } else if ( msg->mode == ActionMessage::AM_MODE_SPECIFIC_ENTRIES ) {
+        if ( activemode != NULL ) {
+          if ( activemode->isType( "NormalMode" ) == true ) {
+              NormalMode *nm1 = dynamic_cast<NormalMode*>( activemode );
+              extlist[0] = new NMExtList();
+              extlist[0]->createExtList( nm1, msg, false );
+              extlist[0]->setTakeDirs( extorder.take_dirs );
+          }
+        }
       }
     }
   }
