@@ -26,11 +26,32 @@
 #include <string>
 #include <aguix/util.h>
 #include "normalmode.h"
+#include "temporaryfilecache.hh"
+#include "datei.h"
+#include "timedtext.hh"
 
 class Worker;
 class ArrayList;
 class SolidButton;
 
+class WPUProgressCallback : public CopyfileProgressCallback
+{
+ public:
+    WPUProgressCallback( Worker *w );
+    ~WPUProgressCallback();
+
+    callback_return_t progress_callback( loff_t current_bytes,
+                                         loff_t total_bytes );
+
+    void setCompleteFilesizes( loff_t sum );
+ private:
+    Worker *m_worker;
+    TimedText m_text;
+    time_t m_last_update;
+    loff_t m_complete_sizes;
+    loff_t m_bytes_already_copied;
+};
+
 class WPUStack
 {
 public:
@@ -39,7 +60,7 @@ public:
   WPUStack( const WPUStack &other );
   WPUStack &operator=( const WPUStack &other );
 
-  void push( std::string elem );
+  void push( const std::string &elem );
   std::string pop();
   std::string top();
   bool isEmpty();
@@ -54,7 +75,7 @@ protected:
 class WPUContext
 {
 public:
-  WPUContext( Worker *, List *coms, ActionMessage *msg = NULL );
+  WPUContext( Worker *, List *coms, bool delete_commands_at_destroy, ActionMessage *msg );
   ~WPUContext();
   WPUContext( const WPUContext &other );
   WPUContext &operator=( const WPUContext &other );
@@ -108,6 +129,8 @@ public:
   void setWinText( const char *str );
   void setTakeDirs( bool nv );
   bool getTakeDirs();
+  void setUseVirtualTempCopies( bool nv );
+  bool getUseVirtualTempCopies() const;
   
   typedef enum { WPU_LASTERROR_STACKEMPTY = 0 } wpu_lasterror_t;
   const char *getBaseDir();
@@ -121,8 +144,10 @@ public:
   int filelistSize( bool other );
   int filelistRealSize( bool other );
 
-  const char *getTempName4File( const char *filename );
-  void freeTempNameList();
+  std::string getTempName4File( const char *filename );
+
+  void ref();
+  int unref();
 protected:
   WPUStack **stacks;
   ArrayList *acoms;
@@ -195,6 +220,15 @@ protected:
     time_t modtime;
   };
   std::list<class temp4filename_t*> tempnamelist;
+
+  bool m_delete_commands_at_destroy;
+  int m_reference_count;
+
+  std::list< TemporaryFileCache::TemporaryFileCacheEntry > m_temp_files;
+  RefCount< WPUProgressCallback > m_progress_callback;
+  bool m_filesizes_calculated;
+
+  void calculateFilesizes();
 };
 
 #endif
